@@ -199,7 +199,7 @@ def main(args: List[str]) -> int: # pylint: disable=missing-function-docstring
       mode = path.stat().st_mode
 
       # fixup permissions, o-rwx g-wx
-      os.chmod(path, mode & ~stat.S_IRWXO & ~stat.S_IWGRP & ~stat.S_IXGRP)
+      path.chmod(mode & ~stat.S_IRWXO & ~stat.S_IWGRP & ~stat.S_IXGRP)
 
       url = upload(package_version, path, str(path)[len("Packages/"):])
       assets.append(url)
@@ -222,8 +222,8 @@ def main(args: List[str]) -> int: # pylint: disable=missing-function-docstring
         webentry[c.suffix[1:]] = url
 
       # only expose a subset of the Windows artifacts
-      if "windows_10_cmake_Release" in str(path) or \
-         "windows_10_msbuild_Release" in str(path):
+      if "/windows/10/cmake/Release/" in str(path) or \
+         "/windows/10/msbuild/Release/" in str(path):
         webdata["windows"].append(webentry)
 
   # various release pages truncate the viewable artifacts to 100 or even 50
