@@ -1,3 +1,8 @@
+/**
+ * @file
+ * @brief creates a geographical map highlighting clusters
+ */
+
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -35,25 +40,23 @@ typedef struct {
     char **infiles; 
     FILE* outfile;
     int dim;
-    real shore_depth_tol;
+    double shore_depth_tol;
     int nrandom; 
     int show_points; 
-    real bbox_margin[2]; 
+    double bbox_margin[2]; 
     int useClusters;
     int clusterMethod;
     bool plotedges;
     int color_scheme;
-    real line_width;
+    double line_width;
     char *color_scheme_str;
-    char *opacity;
-    char *plot_label;
-    real *bg_color;
+    const char *opacity;
     int improve_contiguity_n;
     int nart;
     bool color_optimize;
     int maxcluster;
     int nedgep;
-    char *line_color;
+    const char *line_color;
     int include_OK_points;
     int highlight_cluster;
     int seed;      /* seed used to calculate Fiedler vector */
@@ -125,23 +128,17 @@ static void usage(char* cmd, int eval)
 {
     fprintf(stderr, "Usage: %s <options> graphfile\n", cmd);
     fputs (usestr, stderr);
-    exit(eval);
+    graphviz_exit(eval);
 }
 
-static FILE *openFile(char *name, char *mode, char* cmd)
+static FILE *openFile(const char *name, const char* cmd)
 {
     FILE *fp;
-    char *modestr;
 
-    fp = fopen(name, mode);
+    fp = fopen(name, "w");
     if (!fp) {
-	if (*mode == 'r')
-	    modestr = "reading";
-	else
-	    modestr = "writing";
-	fprintf(stderr, "%s: could not open file %s for %s\n",
-		cmd, name, modestr);
-	exit(-1);
+	fprintf(stderr, "%s: could not open file %s for writing\n", cmd, name);
+	graphviz_exit(-1);
     }
     return (fp);
 }
@@ -154,7 +151,7 @@ init(int argc, char **argv, params_t* pm)
 {
   char* cmd = argv[0];
   int c;
-  real s;
+  double s;
   int v, r;
   char stmp[3];  /* two character string plus '\0' */
 
@@ -171,8 +168,6 @@ init(int argc, char **argv, params_t* pm)
   pm->show_points = 0;
   pm->color_scheme = COLOR_SCHEME_PASTEL; 
   pm->line_width = 0;
-  pm->plot_label = NULL;
-  pm->bg_color = NULL;
   pm->improve_contiguity_n = 0;
   pm->nart = -1;
   pm->color_optimize = true;
@@ -181,7 +176,7 @@ init(int argc, char **argv, params_t* pm)
 
   pm->cmd = cmd;
   pm->infiles = NULL;
-  pm->line_color = strdup("#000000");
+  pm->line_color = "#000000";
   pm->include_OK_points = FALSE;
   pm->seed = 123;
 
@@ -192,7 +187,7 @@ init(int argc, char **argv, params_t* pm)
   while ((c = getopt(argc, argv, ":evODQko:m:s:r:p:c:C:l:b:g:t:a:h:z:d:?")) != -1) {
     switch (c) {
     case 'm':
-      if ((sscanf(optarg,"%lf",&s) > 0) && (s != 0)){
+      if (sscanf(optarg, "%lf", &s) > 0 && s != 0) {
 	    pm->bbox_margin[0] =  pm->bbox_margin[1] = s;
       } else {
         usage(cmd, 1);
@@ -202,34 +197,35 @@ init(int argc, char **argv, params_t* pm)
       pm->clusterMethod = CLUSTERING_MQ;
       break;
     case 's':
-      if ((sscanf(optarg,"%lf",&s) > 0)){
+      if (sscanf(optarg, "%lf", &s) > 0) {
         pm->shore_depth_tol = s;
       } else {
         usage(cmd,1);
       }
       break;
     case 'h':
-      if ((sscanf(optarg,"%d",&v) > 0)){
+      if (sscanf(optarg, "%d", &v) > 0) {
         pm->nedgep = MAX(0, v);
-      } else if (!strncmp(optarg, HLPFX, N_HLPFX) && (sscanf(optarg+N_HLPFX,"%d",&v) > 0)) {
+      } else if (!strncmp(optarg, HLPFX, N_HLPFX) &&
+                 sscanf(optarg + N_HLPFX, "%d", &v) > 0) {
         pm->highlight_cluster = MAX(0, v);
       } else {
         usage(cmd,1);
       }
       break;
      case 'r':
-      if ((sscanf(optarg,"%d",&r) > 0)){
+      if (sscanf(optarg, "%d", &r) > 0) {
         pm->nrandom = r;
       }
       break;
     case 't':
-      if ((sscanf(optarg,"%d",&r) > 0) && r > 0){
+      if (sscanf(optarg, "%d", &r) > 0 && r > 0) {
         pm->improve_contiguity_n = r;
       }
       break;
     case 'p':
       pm->show_points = 1;
-      if ((sscanf(optarg,"%d",&r) > 0)){
+      if (sscanf(optarg, "%d", &r) > 0) {
         pm->show_points = MIN(3, r);
       }
       break;
@@ -246,13 +242,13 @@ init(int argc, char **argv, params_t* pm)
       pm->plotedges = true;
       break;
     case 'o':
-	  pm->outfile = openFile(optarg, "w", pm->cmd);
+	  pm->outfile = openFile(optarg, pm->cmd);
       break;
     case 'O':
       pm->color_optimize = false;
       break;
     case 'a':
-      if ((sscanf(optarg,"%d",&r) > 0)){
+      if (sscanf(optarg, "%d", &r) > 0) {
 	    pm->nart = r;
       } else {
 	    usage(cmd,1);
@@ -260,8 +256,9 @@ init(int argc, char **argv, params_t* pm)
       break;
     case 'c':
       if (sscanf(optarg,"_opacity=%2s", stmp) > 0 && strlen(stmp) == 2){
-        pm->opacity = strdup(stmp);
-      } else if ((sscanf(optarg,"%d",&r) > 0) && r >= COLOR_SCHEME_NONE && r <= COLOR_SCHEME_GREY){
+        pm->opacity = stmp;
+      } else if (sscanf(optarg, "%d", &r) > 0 && r >= COLOR_SCHEME_NONE &&
+                 r <= COLOR_SCHEME_GREY) {
         pm->color_scheme = r;
       } else if (knownColorScheme(optarg)) {
         pm->color_scheme = COLOR_SCHEME_NONE;
@@ -279,25 +276,17 @@ init(int argc, char **argv, params_t* pm)
         pm->seed = v;
       break;
     case 'C':
-      if (!((sscanf(optarg,"%d",&v) > 0) && v >= 0)){
+      if (!(sscanf(optarg, "%d", &v) > 0 && v >= 0)) {
         usage(cmd,1);
       }
       else
         pm->maxcluster = v;
       break;
-    case 'g': {
-      gvcolor_t color;
-      if (colorxlate(optarg, &color, RGBA_DOUBLE) == COLOR_OK) {
-        if (!pm->bg_color) pm->bg_color = N_NEW(3,real);
-        pm->bg_color[0] = color.u.RGBA[0];
-        pm->bg_color[1] = color.u.RGBA[1];
-        pm->bg_color[2] = color.u.RGBA[2];
-      }
+    case 'g':
+      // ignored
       break;
-    }
     case 'z': {
-      FREE (pm->line_color);
-      pm->line_color = strdup (optarg);
+      pm->line_color = optarg;
       break;
     }
     case 'b':
@@ -308,8 +297,7 @@ init(int argc, char **argv, params_t* pm)
       }
       break;
     case 'l':
-      free (pm->plot_label);
-      pm->plot_label = strdup (optarg);
+      // ignored
       break;
     case ':':
       fprintf(stderr, "gvpack: option -%c missing argument - ignored\n", optopt);
@@ -345,15 +333,15 @@ validateCluster (int n, int* grouping, int clust_num)
 }
 
 static void 
-makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping, 
+makeMap (SparseMatrix graph, int n, double* x, double* width, int* grouping, 
   char** labels, float* fsz, float* rgb_r, float* rgb_g, float* rgb_b, params_t* pm, Agraph_t* g )
 {
   int dim = pm->dim;
   int i, flag = 0;
   SparseMatrix poly_lines, polys, poly_point_map;
-  real edge_bridge_tol = 0.;
+  double edge_bridge_tol = 0.;
   int npolys, nverts, *polys_groups, exclude_random;
-  real *x_poly, *xcombined;
+  double *x_poly, *xcombined;
   SparseMatrix country_graph;
   int improve_contiguity_n = pm->improve_contiguity_n;
 #ifdef TIME
@@ -387,7 +375,7 @@ makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping,
   }
 
 #ifdef TIME
-  fprintf(stderr, "map making time = %f\n",((real) (clock() - cpu)) / CLOCKS_PER_SEC);
+  fprintf(stderr, "map making time = %f\n",((double) (clock() - cpu)) / CLOCKS_PER_SEC);
 #endif
 
 
@@ -427,9 +415,9 @@ makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping,
   SparseMatrix_delete(polys);
   SparseMatrix_delete(poly_lines);
   SparseMatrix_delete(poly_point_map);
-  FREE(xcombined);
-  FREE(x_poly);
-  FREE(polys_groups);
+  free(xcombined);
+  free(x_poly);
+  free(polys_groups);
 }
 
 
@@ -437,8 +425,8 @@ static void mapFromGraph (Agraph_t* g, params_t* pm)
 {
     SparseMatrix graph;
   int n;
-  real* width = NULL;
-  real* x;
+  double* width = NULL;
+  double* x;
   char** labels = NULL;
   int* grouping;
   float* rgb_r;
@@ -454,7 +442,7 @@ static void mapFromGraph (Agraph_t* g, params_t* pm)
 
 static Agraph_t *gread(FILE * fp)
 {
-    return agread(fp, (Agdisc_t *) 0);
+    return agread(fp, NULL);
 }
 
 int main(int argc, char *argv[])
@@ -473,5 +461,10 @@ int main(int argc, char *argv[])
     prevg = g;
   }
 
-  return 0; 
+  graphviz_exit(0);
 }
+
+/**
+ * @dir .
+ * @brief creates a geographical map highlighting clusters
+ */
