@@ -8,6 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <cgraph/alloc.h>
 #include "power.h"
 #include <sparse/SparseMatrix.h>
 
@@ -15,10 +16,10 @@
 static const int maxit = 100;
 
 // Accuracy control (convergence criterion) for power_method
-static const real tolerance = 0.00001;
+static const double tolerance = 0.00001;
 
 void power_method(void *A, int n, int K, int random_seed,
-    real **eigv, real *eigs){
+    double **eigv, double *eigs){
   /* find k-largest eigenvectors of a matrix A. Result in eigv. if eigv == NULL; memory will be allocated.
 
      This converges only if the largest eigenvectors/values are real (e.g., if A is symmetric) and the 
@@ -54,20 +55,20 @@ void power_method(void *A, int n, int K, int random_seed,
      end for
      return v1,v2,...
    */
-  real **v, *u, *vv;
+  double **v, *u, *vv;
   int iter = 0;
-  real res, unorm;
+  double res, unorm;
   int i, j, k;
-  real uij;
+  double uij;
 
   K = MAX(0, MIN(n, K));
   assert(K <= n && K > 0);
 
-  if (!(*eigv)) *eigv = MALLOC(sizeof(real)*n*K);
-  v = MALLOC(sizeof(real*)*K);
+  if (!(*eigv)) *eigv = gv_calloc(n * K, sizeof(double));
+  v = gv_calloc(K, sizeof(double*));
 
-  vv = MALLOC(sizeof(real)*n);
-  u = MALLOC(sizeof(real)*n);
+  vv = gv_calloc(n, sizeof(double));
+  u = gv_calloc(n, sizeof(double));
 
   srand(random_seed);
 
@@ -91,7 +92,7 @@ void power_method(void *A, int n, int K, int random_seed,
 	  u[i] = u[i] - uij *v[j][i];
 	}
       }
-      SparseMatrix_multiply_vector(A, u, &vv, FALSE);
+      SparseMatrix_multiply_vector(A, u, &vv);
 
       unorm = vector_product(n, vv, vv);/* ||u||^2 */    
       unorm = sqrt(unorm);
@@ -113,6 +114,6 @@ void power_method(void *A, int n, int K, int random_seed,
       }
     } while (res < 1 - tolerance && iter++ < maxit);
   }
-  FREE(u);
-  FREE(vv);  
+  free(u);
+  free(vv);
 }
