@@ -8,14 +8,10 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#pragma once
 
 /* Lefteris Koutsofios - AT&T Labs Research */
 
-#ifndef _CODE_H
-#define _CODE_H
 #define C_NULL -1
 
 #define C_ISSTMT(ct) (ct >= C_STMT && ct <= C_RETURN)
@@ -74,7 +70,7 @@ typedef struct Code_t {
 } Code_t;
 #define C_CODESIZE sizeof (Code_t)
 
-#define Cgetstring(i) (char *) &cbufp[i].u.s[0]
+#define Cgetstring(i) &cbufp[i].u.s[0]
 #define Cgetindex() cbufi
 
 #define Csettype(a, b) cbufp[a].ctype = b
@@ -94,9 +90,3 @@ int Cnew (int);
 int Cinteger (long);
 int Creal (double);
 int Cstring (char *);
-#endif /* _CODE_H */
-
-#ifdef __cplusplus
-}
-#endif
-
