@@ -17,6 +17,7 @@
 #include "str.h"
 #include "exec.h"
 #include "internal.h"
+#include <stdbool.h>
 #include <string.h>
 
 static lvar_t *lvarp;
@@ -26,8 +27,8 @@ static int lvarn, llvari, flvari;
 
 Tobj root, null;
 Tobj rtno;
-int Erun;
-int Eerrlevel, Estackdepth, Eshowbody, Eshowcalls, Eoktorun;
+bool Erun;
+int Eerrlevel, Estackdepth, Eshowbody;
 
 #define PUSHJMP(op, np, b) op = (volatile jmp_buf *) np, np = (jmp_buf *) &b
 #define POPJMP(op, np) np = (jmp_buf *) op
@@ -74,7 +75,7 @@ static char *errnam[] = {
     "table changed during a forin loop",
 };
 
-static int errdo;
+static bool errdo;
 
 /* stack information */
 typedef struct sinfo_t {
@@ -127,8 +128,8 @@ static void eforinst (Tobj, int);
 static Tobj getval (Tobj, int);
 static int getvar (Tobj, int, tnk_t *);
 static void setvar (tnk_t, Tobj);
-static int boolop (Tobj);
-static int orderop (Tobj, int, Tobj);
+static bool boolop (Tobj);
+static bool orderop (Tobj, int, Tobj);
 static Tobj arithop (Num_t *, int, Num_t *);
 static void err (int, int, Tobj, int);
 static void printbody (char *, int);
@@ -147,9 +148,8 @@ void Einit (void) {
     sinfop = Marrayalloc ((long) SINFOINCR * SINFOSIZE);
     sinfon = SINFOINCR;
     sinfoi = 0;
-    Erun = FALSE;
+    Erun = false;
     running = 0;
-    Eoktorun = FALSE;
 }
 
 void Eterm (void) {
@@ -168,14 +168,6 @@ Tobj Eunit (Tobj co) {
 
     jmp_buf eljbuf;
 
-#if 0
-    if (running && !Eoktorun) {
-        err (ERRRECRUN, ERR2, NULL, 0);
-        return NULL;
-    }
-#endif
-    Eoktorun = FALSE;
-
     if (!co)
         return NULL;
 
@@ -206,7 +198,7 @@ Tobj Eunit (Tobj co) {
     sinfoi = ownsinfoi;
     POPJMP (oeljbufp, eljbufp);
     Mpopmark (m);
-    Erun = TRUE;
+    Erun = true;
     return lrtno;
 }
 
@@ -236,7 +228,7 @@ static Tobj eeval (Tobj co, int ci) {
 
 tailrec:
     m1 = 0;
-    errdo = TRUE;
+    errdo = true;
     v1o = NULL;
     ctype = TCgettype (co, ci);
     switch (ctype) {
@@ -263,19 +255,19 @@ tailrec:
             err (ERRNORHS, ERR4, co, i1);
         switch (ctype) {
         case C_OR:
-            if (boolop (v1o) == TRUE)
+            if (boolop (v1o))
                 return Ttrue;
             if ((v1o = eeval (co, TCgetnext (co, i1))) == NULL)
                 err (ERRNORHS, ERR4, co, TCgetnext (co, i1));
-            return (boolop (v1o) == TRUE) ? Ttrue: Tfalse;
+            return boolop(v1o) ? Ttrue: Tfalse;
         case C_AND:
-            if (boolop (v1o) == FALSE)
+            if (!boolop(v1o))
                 return Tfalse;
             if ((v1o = eeval (co, TCgetnext (co, i1))) == NULL)
                 err (ERRNORHS, ERR4, co, TCgetnext (co, i1));
-            return (boolop (v1o) == FALSE) ? Tfalse: Ttrue;
+            return !boolop(v1o) ? Tfalse: Ttrue;
         case C_NOT:
-            return (boolop (v1o) == TRUE) ? Tfalse: Ttrue;
+            return !boolop(v1o) ? Tfalse: Ttrue;
         }
         /* NOT REACHED */
         return Tfalse;
@@ -294,7 +286,7 @@ tailrec:
             err (ERRNORHS, ERR4, co, TCgetnext (co, i1));
         if (v1o)
             Mpopmark (m1);
-        return (orderop (v1o, ctype, v2o) == TRUE) ? Ttrue: Tfalse;
+        return orderop (v1o, ctype, v2o) ? Ttrue: Tfalse;
     case C_PLUS:
     case C_MINUS:
     case C_MUL:
@@ -388,7 +380,7 @@ tailrec:
         i1 = TCgetfp (co, ci);
         if (!(v1o = eeval (co, i1)))
             err (ERRNORHS, ERR5, co, i1);
-        if (boolop (v1o) == TRUE) {
+        if (boolop(v1o)) {
             ci = TCgetnext (co, i1);
             goto tailrec;
         } else if ((ci = TCgetnext (co, TCgetnext (co, i1))) != C_NULL)
@@ -542,7 +534,7 @@ static Tobj efcall (Tobj co, int ci) {
     sinfoi = ownsinfoi;
     Mpopmark (m);
     lrtno = rtno, rtno = NULL;
-    errdo = TRUE;
+    errdo = true;
     return lrtno;
 }
 
@@ -561,7 +553,7 @@ static void ewhilest (Tobj co, int ci) {
     for (;;) {
         if (!(v1o = eeval ((Tobj) c1o, ei)))
             err (ERRNORHS, ERR5, c1o, ei);
-        if (boolop (v1o) == FALSE)
+        if (!boolop(v1o))
             break;
         if (setjmp (*pljbufp1)) {
             if (pljtype == PLJ_CONTINUE)
@@ -597,7 +589,7 @@ static void eforst (Tobj co, int ci) {
         if (!eisnop2) {
             if (!(v1o = eeval ((Tobj) c1o, ei2)))
                 err (ERRNORHS, ERR5, c1o, ei2);
-            if (boolop (v1o) == FALSE)
+            if (!boolop(v1o))
                 break;
         }
         if (setjmp (*pljbufp1) != 0) {
@@ -823,30 +815,30 @@ static void setvar (tnk_t tnk, Tobj vo) {
     }
 }
 
-static int boolop (Tobj vo) {
+static bool boolop (Tobj vo) {
     long i;
     double d;
 
     if (!vo)
-        return FALSE;
+        return false;
 
     switch (Tgettype (vo)) {
     case T_INTEGER:
         i = Tgetinteger (vo);
-        return (i == 0) ? FALSE : TRUE;
+        return i != 0;
     case T_REAL:
         d = Tgetreal (vo);
-        return (d == 0.0) ? FALSE : TRUE;
+        return !(d == 0.0);
     case T_TABLE:
         if (vo == null)
-            return FALSE;
-        return TRUE;
+            return false;
+        return true;
     default:
-        return TRUE;
+        return true;
     }
 }
 
-static int orderop (Tobj v1o, int op, Tobj v2o) {
+static bool orderop (Tobj v1o, int op, Tobj v2o) {
     int t1, t2;
     long i1, i2;
     int r;
@@ -854,8 +846,8 @@ static int orderop (Tobj v1o, int op, Tobj v2o) {
 
     if (!v1o || !v2o) {
         if ((v1o || v2o) && op == C_NE)
-            return TRUE;
-        return FALSE;
+            return true;
+        return false;
     }
     t1 = Tgettype (v1o), t2 = Tgettype (v2o);
     if (t1 == T_STRING && t2 == T_STRING) {
@@ -874,21 +866,21 @@ static int orderop (Tobj v1o, int op, Tobj v2o) {
         r = (d1 == d2) ? 0 : ((d1 < d2) ? -1 : 1);
     } else if (t1 == t2) {
         if (op != C_EQ && op != C_NE)
-            return FALSE;
+            return false;
         r = (v1o == v2o) ? 0 : 1;
     } else {
-        return FALSE;
+        return false;
     }
     switch (op) {
-    case C_EQ: return (r == 0) ? TRUE : FALSE;
-    case C_NE: return (r != 0) ? TRUE : FALSE;
-    case C_LT: return (r <  0) ? TRUE : FALSE;
-    case C_LE: return (r <= 0) ? TRUE : FALSE;
-    case C_GT: return (r >  0) ? TRUE : FALSE;
-    case C_GE: return (r >= 0) ? TRUE : FALSE;
+    case C_EQ: return r == 0;
+    case C_NE: return r != 0;
+    case C_LT: return r <  0;
+    case C_LE: return r <= 0;
+    case C_GT: return r >  0;
+    case C_GE: return r >= 0;
     }
     panic1 (POS, "orderop", "bad op code");
-    return FALSE; /* NOT REACHED */
+    return false; /* NOT REACHED */
 }
 
 static Tobj arithop (Num_t *lnum, int op, Num_t *rnum) {
@@ -965,7 +957,7 @@ static void err (int errnum, int level, Tobj co, int ci) {
         }
         if (Estackdepth == 1) {
             fprintf (stderr, "\n");
-            errdo = FALSE;
+            errdo = false;
         }
         for (i = si; i >= 0; i--) {
             if (sinfop[i].fco) {
@@ -977,7 +969,7 @@ static void err (int errnum, int level, Tobj co, int ci) {
         printbody (s, Eshowbody), free (s);
     }
     fprintf (stderr, "\n");
-    errdo = FALSE;
+    errdo = false;
 }
 
 static void printbody (char *s, int mode) {
