@@ -1,3 +1,8 @@
+/**
+ * @file
+ * @brief main of lefty
+ */
+
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -15,6 +20,7 @@
 #define LEFTYVERSION "10 Mar 2005"
 
 #include "builddate.h"
+#include <cgraph/exit.h>
 #include "common.h"
 #include "g.h"
 #include "code.h"
@@ -34,6 +40,7 @@
 #include "gmap2l.h"
 #endif
 
+#include <stdbool.h>
 #ifndef FEATURE_MS
 #include <sys/time.h>
 #  ifdef STATS
@@ -60,7 +67,7 @@
 #endif
 
 #ifdef FEATURE_GMAP
-static int gmapon;
+static bool gmapon;
 #endif
 
 static Grect_t txtcoords = {
@@ -111,7 +118,6 @@ int main (int argc, char **argv) {
     Eerrlevel = 1;
     Estackdepth = 2;
     Eshowbody = 1;
-    Eshowcalls = 1;
 
     if (setjmp (exitljbuf))
         goto eop;
@@ -127,7 +133,7 @@ int main (int argc, char **argv) {
     TXTinit (txtcoords);
     GFXinit ();
 #ifdef FEATURE_GMAP
-    gmapon = TRUE, G2Linit ();
+    gmapon = true, G2Linit ();
 #endif
 
     if (exprstr) {
@@ -174,7 +180,7 @@ int main (int argc, char **argv) {
             GMAPupdate ();
 #endif
         if (Erun)
-            TXTupdate (), Erun = FALSE;
+            TXTupdate (), Erun = false;
     }
 eop:
 #ifdef PARANOID
@@ -198,7 +204,7 @@ eop:
     term ();
 #endif
     printusage ();
-    return 0;
+    graphviz_exit(0);
 }
 
 #else
@@ -227,12 +233,11 @@ int APIENTRY WinMain (
     Eerrlevel = 1;
     Estackdepth = 2;
     Eshowbody = 1;
-    Eshowcalls = 1;
 
     processstr (leftyoptions);
     argv = CommandLineToArgvW(lpCmdLine, &argc);
     if (argv == NULL)
-      return EXIT_FAILURE;
+      graphviz_exit(EXIT_FAILURE);
     processargs(argc, argv);
     LocalFree(argv);
 
@@ -285,7 +290,7 @@ int APIENTRY WinMain (
                 processinput (TRUE);
         }
         if (Erun)
-            TXTupdate (), Erun = FALSE;
+            TXTupdate (), Erun = false;
     }
 
 eop:
@@ -305,7 +310,7 @@ eop:
     term ();
 #endif
     printusage ();
-    exit (0);
+    graphviz_exit(0);
 }
 
 #endif
@@ -410,7 +415,7 @@ static void usage(int eval)
 {
     fprintf (stderr, "Usage: lefty [options] [file]\n");
     fputs (usestr, stderr);
-    exit (eval);
+    graphviz_exit(eval);
 }
 
 static void processstr (char *buf) {
@@ -450,7 +455,7 @@ static void processargs (int argc, char *argv[]) {
         else if (strcmp (argv[0], "-sb") == 0)
             Eshowbody = atoi (argv[1]), argv++, argc--;
         else if (strcmp (argv[0], "-sc") == 0)
-            Eshowcalls = atoi (argv[1]), argv++, argc--;
+            argv++, argc--;
         else if (strcmp (argv[0], "-df") == 0)
             Gdefaultfont = argv[1], argv++, argc--;
         else if (strcmp (argv[0], "-w") == 0)
@@ -476,7 +481,7 @@ static void processargs (int argc, char *argv[]) {
                 fclose(fp);
             if ((fp = fopen (argv[0], "r")) == NULL) {
                 fprintf (stderr, "cannot open input file: %s\n", argv[0]);
-                exit(2);
+                graphviz_exit(2);
             }
         }
         argv++, argc--;
@@ -519,3 +524,17 @@ static void printusage (void) {
     fflush (stdout);
 #endif
 }
+
+/**
+ * @dir .
+ * @brief a programmable graphics editor
+ *
+ * @dir ../lneato
+ * @brief lefty + neato
+ *
+ * @dir ../dotty
+ * @brief dot + lefty
+ *
+ * @dir ../../cmd
+ * @brief Graph programs
+ */
