@@ -13,6 +13,7 @@
 #include "gui.h"
 #include "viewport.h"
 #include "gltemplate.h"
+#include <cgraph/exit.h>
 #include <glcomp/glutils.h>
 #include "glexpose.h"
 #include "glmotion.h"
@@ -58,7 +59,7 @@ static void print_gl_config_attrib(GdkGLConfig * glconfig,
     g_print("%s = ", attrib_str);
     if (gdk_gl_config_get_attrib(glconfig, attrib, &value)) {
 	if (is_boolean)
-	    g_print("%s\n", value == TRUE ? "TRUE" : "FALSE");
+	    g_print("%s\n", value ? "TRUE" : "FALSE");
 	else
 	    g_print("%d\n", value);
     } else
@@ -246,7 +247,7 @@ gboolean expose_event(GtkWidget * widget, GdkEventExpose * event,
     if (view->initFile) {
 	view->initFile = 0;
 	if (view->activeGraph == 0)
-	    close_graph(view, 0);
+	    close_graph(view);
 	add_graph_to_viewport_from_file(view->initFileName);
     }
     return TRUE;
@@ -427,7 +428,7 @@ GdkGLConfig *configure_gl(void)
 					     GDK_GL_MODE_DEPTH);
 	if (glconfig == NULL) {
 	    g_print("*** No appropriate OpenGL-capable visual found.\n");
-	    exit(1);
+	    graphviz_exit(1);
 	}
     }
 
