@@ -13,7 +13,6 @@
 #include "builddate.h"
 //windows.h for win machines
 #if defined(_WIN32) && !defined(__CYGWIN__)
-#define WIN32_LEAN_AND_MEAN 1
 #include <windows.h>
 #include <windowsx.h>
 #endif
@@ -25,6 +24,7 @@
 #include "support.h"
 #include "menucallbacks.h"
 #include "gltemplate.h"
+#include <cgraph/exit.h>
 #include <common/memory.h>
 #include "gvprpipe.h"
 #include "frmobjectui.h"
@@ -36,17 +36,10 @@
 #include "glutrender.h"
 
 #include <getopt.h>
+#include <stddef.h>
 
-#ifdef G_OS_WIN32
-gchar *package_prefix;
-gchar *package_data_dir;
-#endif
-gchar *package_locale_dir;
 static char *smyrnaDir;		/* path to directory containin smyrna data files */
-char *smyrnaGlade;
-unsigned char SmyrnaVerbose;
-int width,height;/*glut window size*/
-
+static char *smyrnaGlade;
 
 /* smyrnaPath:
  * Construct pathname for smyrna data file.
@@ -60,8 +53,7 @@ int width,height;/*glut window size*/
 char *smyrnaPath(char *suffix)
 {
     char *buf;
-    static int baselen;
-    int slen;
+    static size_t baselen;
 #ifdef _WIN32
     char *pathSep = "\\";
 #else
@@ -70,9 +62,9 @@ char *smyrnaPath(char *suffix)
     assert(smyrnaDir);
 
     if (baselen == 0) {
-	baselen = (int)strlen(smyrnaDir) + 2;
+	baselen = strlen(smyrnaDir) + 2;
     }
-    slen = (int)strlen(suffix);
+    size_t slen = strlen(suffix);
     buf = N_NEW(baselen+slen, char);
     sprintf(buf, "%s%s%s", smyrnaDir, pathSep, suffix);
     return buf;
@@ -87,7 +79,7 @@ static char *useString = "Usage: smyrna [-v?] <file>\n\
 static void usage(int v)
 {
     fputs(useString, stdout);
-    exit(v);
+    graphviz_exit(v);
 }
 
 static char *Info[] = {
@@ -106,8 +98,7 @@ static char *parseArgs(int argc, char *argv[], ViewInfo * view)
 	case 'e':
 	    view->drawSplines = 1;
 	    break;
-	case 'v':
-	    SmyrnaVerbose = 1;
+	case 'v': // FIXME: deprecate and remove -v in future
 	    break;
 	case 'f':
 	    view->guiMode=GUI_FULLSCREEN;
@@ -117,10 +108,10 @@ static char *parseArgs(int argc, char *argv[], ViewInfo * view)
 	case 'V':
 	    fprintf(stderr, "%s version %s (%s)\n",
 		    Info[0], Info[1], Info[2]);
-	    exit (0);
+	    graphviz_exit(0);
 	    break;
 	case '?':
-	    if (optopt == '\0')
+	    if (optopt == '\0' || optopt == '?')
 		usage(0);
 	    else {
 		fprintf(stderr,
@@ -152,8 +143,7 @@ static void windowedMode(int argc, char *argv[])
 
     gladewidget = glade_xml_get_widget(xml, "frmMain");
     gtk_widget_show(gladewidget);
-    g_signal_connect((gpointer) gladewidget, "destroy",
-		     G_CALLBACK(mQuitSlot), NULL);
+    g_signal_connect(gladewidget, "destroy", G_CALLBACK(mQuitSlot), NULL);
     glade_xml_signal_autoconnect(xml);
     gtk_gl_init(0, 0);
     /* Configure OpenGL framebuffer. */
@@ -198,12 +188,12 @@ int main(int argc, char *argv[])
 
 	if (VirtualQuery (&main, &mbi, sizeof(mbi)) == 0) {
 	    fprintf (stderr,"failed to get handle for executable.\n");
-	    return 1;
+	    graphviz_exit(1);
 	}
 	r = GetModuleFileName ((HMODULE)mbi.AllocationBase, line, BSZ);
 	if (!r || (r == BSZ)) {
 	    fprintf (stderr,"failed to get path for executable.\n");
-	    return 1;
+	    graphviz_exit(1);
 	}
 
 	/* line contains path to smyrna: "$GVROOT\bin\smyrna.exe" 
@@ -213,12 +203,12 @@ int main(int argc, char *argv[])
 	s = strrchr(line,'\\');
 	if (!s) {
 	    fprintf (stderr,"no backslash in path %s.\n", line);
-	    return 1;
+	    graphviz_exit(1);
 	}
 	while ((s != line) && (*(--s) != '\\')) ;
 	if (s == line) {
 	    fprintf (stderr,"no backslash in path %s.\n", line);
-	    return 1;
+	    graphviz_exit(1);
 	}
 	*s = '\0';
 
@@ -231,10 +221,11 @@ int main(int argc, char *argv[])
     }
     load_attributes();
 
+    gchar *package_locale_dir;
 #ifdef G_OS_WIN32
-    package_prefix =
+    gchar *package_prefix =
 	g_win32_get_package_installation_directory(NULL, NULL);
-    package_data_dir = g_build_filename(package_prefix, "share", NULL);
+    gchar *package_data_dir = g_build_filename(package_prefix, "share", NULL);
     package_locale_dir =
 	g_build_filename(package_prefix, "share", "locale", NULL);
 #else
@@ -252,7 +243,7 @@ int main(int argc, char *argv[])
 	view->initFile=1;
 
     if(view->guiMode==GUI_FULLSCREEN)
-	cb_glutinit(0,0,800,600,32,75,1,&argc,argv,view->optArg);
+	cb_glutinit(800, 600, &argc, argv, view->optArg);
     else
 	windowedMode(argc, argv);
 #ifdef G_OS_WIN32
@@ -260,5 +251,10 @@ int main(int argc, char *argv[])
     g_free(package_data_dir);
 #endif
     g_free(package_locale_dir);
-    return 0;
+    graphviz_exit(0);
 }
+
+/**
+ * @dir .
+ * @brief interactive graph viewer
+ */
