@@ -1,3 +1,8 @@
+/**
+ * @file
+ * @brief flow colors through a ranked digraph
+ */
+
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -14,12 +19,13 @@
  * Updated by Emden Gansner
  */
 
-#include "config.h"
-
 /* if NC changes, a bunch of scanf calls below are in trouble */
 #define	NC	3		/* size of HSB color vector */
 
+#include <assert.h>
 #include <cgraph/cgraph.h>
+#include <cgraph/exit.h>
+#include <math.h>
 #include <stdlib.h>
 typedef struct Agnodeinfo_t {
     Agrec_t h;
@@ -32,9 +38,6 @@ typedef struct Agnodeinfo_t {
 
 #include <ingraphs/ingraphs.h>
 #include <stdio.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
 
 #include <getopt.h>
 
@@ -62,7 +65,7 @@ static int cmpf(Agnode_t ** n0, Agnode_t ** n1)
 static void setcolor(char *p, double *v)
 {
     char buf[64];
-    if ((sscanf(p, "%lf %lf %lf", v, v + 1, v + 2) != 3) && p[0]) {
+    if (sscanf(p, "%lf %lf %lf", v, v + 1, v + 2) != 3 && p[0]) {
 	colorxlate(p, buf);
 	sscanf(buf, "%lf %lf %lf", v, v + 1, v + 2);
     }
@@ -77,7 +80,7 @@ If no files are specified, stdin is used\n";
 static void usage(int v)
 {
     printf("%s",useString);
-    exit(v);
+    graphviz_exit(v);
 }
 
 static void init(int argc, char *argv[])
@@ -96,6 +99,9 @@ static void init(int argc, char *argv[])
 		usage(1);
 	    }
 	    break;
+	default:
+	    fprintf(stderr, "gvcolor: unexpected error\n");
+	    graphviz_exit(EXIT_FAILURE);
 	}
     }
     argv += optind;
@@ -107,7 +113,7 @@ static void init(int argc, char *argv[])
 
 static void color(Agraph_t * g)
 {
-    int nn, i, j, cnt;
+    int nn, j, cnt;
     Agnode_t *n, *v, **nlist;
     Agedge_t *e;
     char *p;
@@ -117,7 +123,7 @@ static void color(Agraph_t * g)
     if (agattr(g, AGNODE, "pos", 0) == NULL) {
 	fprintf(stderr,
 		"graph must be run through 'dot' before 'gvcolor'\n");
-	exit(1);
+	graphviz_exit(1);
     }
     aginit(g, AGNODE, "nodeinfo", sizeof(Agnodeinfo_t), TRUE);
     if (agattr(g, AGNODE, "style", 0) == NULL)
@@ -125,9 +131,9 @@ static void color(Agraph_t * g)
     if ((p = agget(g, "Defcolor")))
 	setcolor(p, Defcolor);
 
-    if ((p = agget(g, "rankdir")) && (p[0] == 'L'))
+    if ((p = agget(g, "rankdir")) && p[0] == 'L')
 	LR = 1;
-    if ((p = agget(g, "flow")) && (p[0] == 'b'))
+    if ((p = agget(g, "flow")) && p[0] == 'b')
 	Forward = 0;
     if ((p = agget(g, "saturation"))) {
 	if (sscanf(p, "%lf,%lf", &lowsat, &highsat) == 2) {
@@ -139,8 +145,10 @@ static void color(Agraph_t * g)
 
     /* assemble the sorted list of nodes and store the initial colors */
     nn = agnnodes(g);
-    nlist = malloc(nn * sizeof(Agnode_t *));
-    i = 0;
+    assert(nn >= 0);
+    size_t nnodes = (size_t)nn;
+    nlist = malloc(nnodes * sizeof(Agnode_t *));
+    size_t i = 0;
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	nlist[i++] = n;
 	if ((p = agget(n, "color")))
@@ -148,19 +156,18 @@ static void color(Agraph_t * g)
 	p = agget(n, "pos");
 	sscanf(p, "%lf,%lf", &x, &y);
 	ND_relrank(n) = (LR ? x : y);
-	if (maxrank < ND_relrank(n))
-	    maxrank = ND_relrank(n);
+	maxrank = fmax(maxrank, ND_relrank(n));
     }
     if (LR != Forward)
-	for (i = 0; i < nn; i++) {
+	for (i = 0; i < nnodes; i++) {
 	    n = nlist[i];
 	    ND_relrank(n) = maxrank - ND_relrank(n);
 	}
-    qsort((void *) nlist, (size_t) nn, sizeof(Agnode_t *),
+    qsort(nlist, nnodes, sizeof(Agnode_t *),
 	  (int (*)(const void *, const void *)) cmpf);
 
     /* this is the pass that pushes the colors through the edges */
-    for (i = 0; i < nn; i++) {
+    for (i = 0; i < nnodes; i++) {
 	n = nlist[i];
 
 	/* skip nodes that were manually colored */
@@ -195,7 +202,7 @@ static void color(Agraph_t * g)
     }
 
     /* apply saturation adjustment and convert color to string */
-    for (i = 0; i < nn; i++) {
+    for (i = 0; i < nnodes; i++) {
 	double h, s, b, t;
 	char buf[64];
 
@@ -229,7 +236,7 @@ static void color(Agraph_t * g)
 
 static Agraph_t *gread(FILE * fp)
 {
-    return agread(fp, (Agdisc_t *) 0);
+    return agread(fp, NULL);
 }
 
 int main(int argc, char **argv)
@@ -247,5 +254,5 @@ int main(int argc, char **argv)
 	agclose(g);
     }
 
-    exit(0);
+    graphviz_exit(0);
 }
