@@ -1,3 +1,8 @@
+/**
+ * @file
+ * @brief <a href=https://math.nist.gov/MatrixMarket/>Matrix Market</a>-DOT converter
+ */
+
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -9,9 +14,11 @@
  *************************************************************************/
 
 #include "config.h"
+#include <cgraph/unreachable.h>
 
 #define STANDALONE
 #include <cgraph/cgraph.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -23,10 +30,6 @@
 #include "matrix_market.h"
 #include <getopt.h>
 
-#define MALLOC malloc
-#define FREE free
-#define test_flag(a, flag) ((a)&(flag))
-#define real double
 #define BUFS         1024
 
 typedef struct {
@@ -38,42 +41,42 @@ typedef struct {
 
 static char *cmd;
 
-static real Hue2RGB(real v1, real v2, real H)
+static double Hue2RGB(double v1, double v2, double H)
 {
     if (H < 0.0)
 	H += 1.0;
     if (H > 1.0)
 	H -= 1.0;
-    if ((6.0 * H) < 1.0)
+    if (6.0 * H < 1.0)
 	return (v1 + (v2 - v1) * 6.0 * H);
-    if ((2.0 * H) < 1.0)
+    if (2.0 * H < 1.0)
 	return v2;
-    if ((3.0 * H) < 2.0)
-	return (v1 + (v2 - v1) * ((2.0 / 3.0) - H) * 6.0);
+    if (3.0 * H < 2.0)
+	return v1 + (v2 - v1) * (2.0 / 3.0 - H) * 6.0;
     return v1;
 }
 
-static char *hue2rgb(real hue, char *color)
+static char *hue2rgb(double hue, char *color)
 {
-    real v1, v2, lightness = .5, saturation = 1;
+    double v1, v2, lightness = .5, saturation = 1;
     int red, blue, green;
 
     if (lightness < 0.5)
 	v2 = lightness * (1.0 + saturation);
     else
-	v2 = (lightness + saturation) - (saturation * lightness);
+	v2 = lightness + saturation - saturation * lightness;
 
     v1 = 2.0 * lightness - v2;
 
-    red = (int) (255.0 * Hue2RGB(v1, v2, hue + (1.0 / 3.0)) + 0.5);
+    red = (int) (255.0 * Hue2RGB(v1, v2, hue + 1.0 / 3.0) + 0.5);
     green = (int) (255.0 * Hue2RGB(v1, v2, hue) + 0.5);
-    blue = (int) (255.0 * Hue2RGB(v1, v2, hue - (1.0 / 3.0)) + 0.5);
+    blue = (int) (255.0 * Hue2RGB(v1, v2, hue - 1.0 / 3.0) + 0.5);
     sprintf(color, "#%02x%02x%02x", red, green, blue);
     return color;
 }
 
 static Agraph_t *makeDotGraph(SparseMatrix A, char *name, int dim,
-			      real * x, int with_color, int with_label, int with_val)
+			      double * x, int with_color, int with_label, int with_val)
 {
     Agraph_t *g;
     Agnode_t *n;
@@ -82,32 +85,32 @@ static Agraph_t *makeDotGraph(SparseMatrix A, char *name, int dim,
     int i, j;
     agxbuf xb;
     char buf[BUFS];
-    unsigned char string[BUFS];
-    Agsym_t *sym, *sym2 = NULL, *sym3 = NULL;
+    char string[BUFS];
+    Agsym_t *sym = NULL, *sym2 = NULL, *sym3 = NULL;
     int *ia = A->ia;
     int *ja = A->ja;
-    real *val = (real *) (A->a);
+    double *val = A->a;
     Agnode_t **arr = N_NEW(A->m, Agnode_t *);
-    real *color = NULL;
+    double *color = NULL;
     char cstring[8];
 
     name = strip_dir(name);
 
     if (with_color) {
-	if ((A->type == MATRIX_TYPE_REAL) && !val) {
+	if (A->type == MATRIX_TYPE_REAL && !val) {
 	    fprintf (stderr, "Warning: input matrix has no values, -c flag ignored\n");
 	    with_color = 0;
 	}
-	else if ((A->type != MATRIX_TYPE_REAL) && !x) {
+	else if (A->type != MATRIX_TYPE_REAL && !x) {
 	    fprintf (stderr, "Warning: input has no coordinates, -c flag ignored\n");
 	    with_color = 0;
 	}
     }
 
     if (SparseMatrix_known_undirected(A)) {
-	g = agopen("G", Agundirected, (Agdisc_t *) 0);
+	g = agopen("G", Agundirected, NULL);
     } else {
-	g = agopen("G", Agdirected, (Agdisc_t *) 0);
+	g = agopen("G", Agdirected, NULL);
     }
 
     if (with_val) {
@@ -122,20 +125,20 @@ static Agraph_t *makeDotGraph(SparseMatrix A, char *name, int dim,
     for (i = 0; i < A->m; i++) {
 	sprintf(buf, "%d", i);
 	n = agnode(g, buf, 1);
-	agbindrec(n, "nodeinfo", sizeof(Agnodeinfo_t), TRUE);
+	agbindrec(n, "nodeinfo", sizeof(Agnodeinfo_t), true);
 	ND_id(n) = i;
 	arr[i] = n;
     }
 
     if (with_color) {
-	real maxdist = 0.;
-	real mindist = 0.;
+	double maxdist = 0.;
+	double mindist = 0.;
 	int first = TRUE;
 
 	sym2 = agattr(g, AGEDGE, "color", "");
 	sym3 = agattr(g, AGEDGE, "wt", "");
 	agattr(g, AGRAPH, "bgcolor", "black");
-	color = N_NEW(A->nz, real);
+	color = N_NEW(A->nz, double);
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	    i = ND_id(n);
 	    if (A->type != MATRIX_TYPE_REAL) {
@@ -170,9 +173,7 @@ static Agraph_t *makeDotGraph(SparseMatrix A, char *name, int dim,
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	    i = ND_id(n);
 	    for (j = ia[i]; j < ia[i + 1]; j++) {
-		color[j] =
-		    ((color[j] - mindist) / MAX(maxdist - mindist,
-						0.000001));
+		color[j] = (color[j] - mindist) / MAX(maxdist - mindist, 0.000001);
 	    }
 	}
     }
@@ -182,7 +183,7 @@ static Agraph_t *makeDotGraph(SparseMatrix A, char *name, int dim,
 	for (j = ia[i]; j < ia[i + 1]; j++) {
 	    h = arr[ja[j]];
 	    e = agedge(g, n, h, NULL, 1);
-	    if (with_val && val) {
+	    if (sym && val) {
 		sprintf(buf, "%f", val[j]);
 		agxset(e, sym, buf);
 	    }
@@ -195,8 +196,8 @@ static Agraph_t *makeDotGraph(SparseMatrix A, char *name, int dim,
     }
 
     agxbfree (&xb);
-    FREE(color);
-    FREE(arr);
+    free(color);
+    free(arr);
     return g;
 }
 
@@ -215,7 +216,7 @@ static char* useString = "Usage: %s [-uvcl] [-o file] matrix_market_filename\n\
 static void usage(int eval)
 {
     fprintf(stderr, useString, cmd);
-    exit(eval);
+    graphviz_exit(eval);
 }
 
 static FILE *openF(char *fname, char *mode)
@@ -223,8 +224,8 @@ static FILE *openF(char *fname, char *mode)
     FILE *f = fopen(fname, mode);
     if (!f) {
 	fprintf(stderr, "Could not open %s for %s\n", fname,
-		((*mode == 'r') ? "reading" : "writing"));
-	exit(1);
+		*mode == 'r' ? "reading" : "writing");
+	graphviz_exit(1);
     }
     return f;
 }
@@ -285,6 +286,8 @@ static void init(int argc, char **argv, parms_t * p)
 		usage(1);
 	    }
 	    break;
+ 	default:
+	    UNREACHABLE();
 	}
     }
     argv += optind;
@@ -316,7 +319,7 @@ int main(int argc, char *argv[])
 
     /* ======================= read graph ==================== */
 
-    A = SparseMatrix_import_matrix_market(pv.inf, FORMAT_CSR);
+    A = SparseMatrix_import_matrix_market(pv.inf);
     if (!A) {
 	fprintf (stderr, "Unable to read input file \"%s\"\n", pv.infile); 
 	usage(1);
@@ -326,7 +329,7 @@ int main(int argc, char *argv[])
 
     if (!A) {
 	fprintf(stderr, "cannot import from file %s\n", pv.infile);
-	exit(1);
+	graphviz_exit(1);
     }
 
     if (pv.undirected) {
@@ -339,6 +342,6 @@ int main(int argc, char *argv[])
 
     agwrite(g, pv.outf);
 
-    return 0;
+    graphviz_exit(0);
 }
 
