@@ -19,22 +19,17 @@ extern "C" {
 
     typedef Dict_t PointSet;
     typedef Dict_t PointMap;
+
 #ifdef GVDLL
+#ifdef GVC_EXPORTS
 #define POINTSET_API __declspec(dllexport)
 #else
-#define POINTSET_API
-#endif
-
-/*visual studio*/
-#ifdef _WIN32
-#ifndef GVC_EXPORTS
-#undef POINTSET_API
 #define POINTSET_API __declspec(dllimport)
 #endif
 #endif
-/*end visual studio*/
+
 #ifndef POINTSET_API
-#define POINTSET_API extern
+#define POINTSET_API /* nothing */
 #endif
 
 	POINTSET_API PointSet *newPS(void);
@@ -50,7 +45,6 @@ extern "C" {
     POINTSET_API void clearPM(PointMap *);
     POINTSET_API void freePM(PointMap *);
     POINTSET_API int insertPM(PointMap *, int, int, int);
-    POINTSET_API int updatePM(PointMap * pm, int x, int y, int v);
 
 #undef POINTSET_API
 #ifdef __cplusplus
