@@ -17,14 +17,8 @@
 #include <gvc/gvc.h>
 #include <cgraph/strcasecmp.h>
 #include <stddef.h>
-
-#ifdef _WIN32
-#define R_OK 4
-#endif
-
-#ifdef HAVE_UNISTD_H
-#   include <unistd.h>
-#endif // HAVE_UNISTD_H
+#include <stdbool.h>
+#include <unistd.h>
 
 #include <ctype.h>
 
@@ -134,7 +128,7 @@ char *late_nnstring(void *obj, attrsym_t * attr, char *def)
     return rv;
 }
 
-boolean late_bool(void *obj, attrsym_t * attr, int def)
+bool late_bool(void *obj, attrsym_t * attr, bool def)
 {
     if (attr == NULL)
 	return def;
@@ -181,13 +175,6 @@ node_t *UF_union(node_t * u, node_t * v)
     return v;
 }
 
-void UF_remove(node_t * u, node_t * v)
-{
-    assert(ND_UF_size(u) == 1);
-    ND_UF_parent(u) = u;
-    ND_UF_size(v) -= ND_UF_size(u);
-}
-
 void UF_singleton(node_t * u)
 {
     ND_UF_size(u) = 1;
@@ -278,10 +265,10 @@ Agnodeinfo_t* ND_info(node_t * n) { return ((Agnodeinfo_t*)AGDATA(n));}
  */
 char *Fgets(FILE * fp)
 {
-    static int bsize = 0;
+    static size_t bsize = 0;
     static char *buf;
     char *lp;
-    int len;
+    size_t len;
 
     len = 0;
     do {
@@ -289,7 +276,7 @@ char *Fgets(FILE * fp)
 	    bsize += BUFSIZ;
 	    buf = grealloc(buf, bsize);
 	}
-	lp = fgets(buf + len, bsize - len, fp);
+	lp = fgets(buf + len, (int)(bsize - len), fp);
 	if (lp == 0)
 	    break;
 	len += strlen(lp);	/* since lp != NULL, len > 0 */
@@ -333,13 +320,13 @@ char *Fgets(FILE * fp)
 #define PATHSEP ":"
 #endif
 
-static char** mkDirlist (const char* list, int* maxdirlen)
+static char** mkDirlist (const char* list, size_t* maxdirlen)
 {
     int cnt = 0;
     char* s = strdup (list);
     char* dir;
     char** dirs = NULL;
-    int maxlen = 0;
+    size_t maxlen = 0;
 
     for (dir = strtok (s, PATHSEP); dir; dir = strtok (NULL, PATHSEP)) {
 	dirs = ALLOC (cnt+2,dirs,char*);
@@ -351,7 +338,7 @@ static char** mkDirlist (const char* list, int* maxdirlen)
     return dirs;
 }
 
-static char* findPath (char** dirs, int maxdirlen, const char* str)
+static char* findPath (char** dirs, size_t maxdirlen, const char* str)
 {
     static char *safefilename = NULL;
     char** dp;
@@ -360,7 +347,7 @@ static char* findPath (char** dirs, int maxdirlen, const char* str)
          * +1 for null character.
          * +1 for directory separator character.
          */
-    safefilename = realloc(safefilename, (maxdirlen + strlen(str) + 2));
+    safefilename = realloc(safefilename, maxdirlen + strlen(str) + 2);
 
     for (dp = dirs; *dp; dp++) {
 	sprintf (safefilename, "%s%s%s", *dp, DIRSEP, str);
@@ -372,9 +359,9 @@ static char* findPath (char** dirs, int maxdirlen, const char* str)
 
 const char *safefile(const char *filename)
 {
-    static boolean onetime = TRUE;
+    static bool onetime = true;
     static char *pathlist = NULL;
-    static int maxdirlen;
+    static size_t maxdirlen;
     static char** dirs;
     const char *str, *p;
 
@@ -393,7 +380,7 @@ const char *safefile(const char *filename)
 		      "file loading is disabled because the environment contains SERVER_NAME=\"%s\"\n"
 		      "and the GV_FILE_PATH variable is unset or empty.\n",
 		      HTTPServerEnVar);
-		onetime = FALSE;
+		onetime = false;
 	    }
 	    return NULL;
 	}
@@ -414,7 +401,7 @@ const char *safefile(const char *filename)
 	    agerr(AGWARN, "Path provided to file: \"%s\" has been ignored"
 		  " because files are only permitted to be loaded from the directories in \"%s\""
 		  " when running in an http server.\n", filename, Gvfilepath);
-	    onetime = FALSE;
+	    onetime = false;
 	}
 
 	return findPath (dirs, maxdirlen, str);
@@ -448,27 +435,27 @@ int maptoken(char *p, char **name, int *val)
     return val[i];
 }
 
-boolean mapBool(char *p, boolean dflt)
+bool mapBool(const char *p, bool dflt)
 {
-    if (!p || (*p == '\0'))
+    if (!p || *p == '\0')
 	return dflt;
     if (!strcasecmp(p, "false"))
-	return FALSE;
+	return false;
     if (!strcasecmp(p, "no"))
-	return FALSE;
+	return false;
     if (!strcasecmp(p, "true"))
-	return TRUE;
+	return true;
     if (!strcasecmp(p, "yes"))
-	return TRUE;
-    if (isdigit(*p))
-	return atoi(p);
+	return true;
+    if (isdigit((int)*p))
+	return atoi(p) != 0;
     else
 	return dflt;
 }
 
-boolean mapbool(char *p)
+bool mapbool(const char *p)
 {
-    return mapBool (p, FALSE);
+    return mapBool(p, false);
 }
 
 pointf dotneato_closest(splines * spl, pointf pt)
@@ -587,13 +574,6 @@ pointf spline_at_y(splines * spl, double y)
     return p;
 }
 
-pointf neato_closest(splines * spl, pointf p)
-{
-/* this is a stub so that we can share a common emit.c between dot and neato */
-
-    return spline_at_y(spl, p.y);
-}
-
 static int Tflag;
 void gvToggle(int s)
 {
@@ -662,16 +642,16 @@ initFontLabelEdgeAttr(edge_t * e, struct fontinfo *fi,
  * Return true if head/tail end of edge should not be clipped
  * to node.
  */
-static boolean
+static bool
 noClip(edge_t *e, attrsym_t* sym)
 {
     char		*str;
-    boolean		rv = FALSE;
+    bool rv = false;
 
     if (sym) {	/* mapbool isn't a good fit, because we want "" to mean true */
 	str = agxget(e,sym);
 	if (str && str[0]) rv = !mapbool(str);
-	else rv = FALSE;
+	else rv = false;
     }
     return rv;
 }
@@ -716,7 +696,7 @@ int common_init_edge(edge_t * e)
 				fi.fontsize, fi.fontname, fi.fontcolor);
 	GD_has_labels(sg) |= EDGE_LABEL;
 	ED_label_ontop(e) =
-	    mapbool(late_string(e, E_label_float, "false"));
+	    mapbool(late_string(e, E_label_float, "false")) ? TRUE : FALSE;
     }
 
     if (E_xlabel && (str = agxget(e, E_xlabel)) && (str[0])) {
@@ -752,25 +732,25 @@ int common_init_edge(edge_t * e)
     /* libgraph always defines tailport/headport; libcgraph doesn't */
     if (!str) str = "";
     if (str && str[0])
-	ND_has_port(agtail(e)) = TRUE;
+	ND_has_port(agtail(e)) = true;
     ED_tail_port(e) = chkPort (ND_shape(agtail(e))->fns->portfn, agtail(e), str);
     if (noClip(e, E_tailclip))
-	ED_tail_port(e).clip = FALSE;
+	ED_tail_port(e).clip = false;
     str = agget(e, HEAD_ID);
     /* libgraph always defines tailport/headport; libcgraph doesn't */
     if (!str) str = "";
     if (str && str[0])
-	ND_has_port(aghead(e)) = TRUE;
+	ND_has_port(aghead(e)) = true;
     ED_head_port(e) = chkPort(ND_shape(aghead(e))->fns->portfn, aghead(e), str);
     if (noClip(e, E_headclip))
-	ED_head_port(e).clip = FALSE;
+	ED_head_port(e).clip = false;
 
     return r;
 }
 
 /* addLabelBB:
  */
-static boxf addLabelBB(boxf bb, textlabel_t * lp, boolean flipxy)
+static boxf addLabelBB(boxf bb, textlabel_t * lp, bool flipxy)
 {
     double width, height;
     pointf p = lp->pos;
@@ -900,9 +880,10 @@ void compute_bb(graph_t * g)
     GD_bb(g) = bb;
 }
 
-int is_a_cluster (Agraph_t* g)
+bool is_a_cluster (Agraph_t* g)
 {
-    return ((g == g->root) || (!strncasecmp(agnameof(g), "cluster", 7)) || mapBool(agget(g,"cluster"),FALSE));
+  return g == g->root || !strncasecmp(agnameof(g), "cluster", 7) ||
+         mapBool(agget(g, "cluster"), false);
 }
 
 /* setAttr:
@@ -944,7 +925,7 @@ static node_t *clustNode(node_t * n, graph_t * cg, agxbuf * xb,
     agxbprint(xb, "__%d:%s", idx++, agnameof(cg));
 
     cn = agnode(agroot(cg), agxbuse(xb), 1);
-    agbindrec(cn, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);
+    agbindrec(cn, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);
 
     SET_CLUST_NODE(cn);
 	agsubnode(cg,cn,1);
@@ -967,8 +948,8 @@ typedef struct {
 
 static int cmpItem(Dt_t * d, void *p1[], void *p2[], Dtdisc_t * disc)
 {
-    NOTUSED(d);
-    NOTUSED(disc);
+    (void)d;
+    (void)disc;
 
     if (p1[0] < p2[0])
 	return -1;
@@ -986,9 +967,10 @@ static int cmpItem(Dt_t * d, void *p1[], void *p2[], Dtdisc_t * disc)
  */
 static void *newItem(Dt_t * d, item * objp, Dtdisc_t * disc)
 {
+    (void)d;
     item *newp = NEW(item);
 
-    NOTUSED(disc);
+    (void)disc;
     newp->p[0] = objp->p[0];
     newp->p[1] = objp->p[1];
     newp->t = objp->t;
@@ -1001,19 +983,18 @@ static void *newItem(Dt_t * d, item * objp, Dtdisc_t * disc)
  */
 static void freeItem(Dt_t * d, item * obj, Dtdisc_t * disc)
 {
+    (void)d;
+    (void)disc;
     free(obj);
 }
 
 static Dtdisc_t mapDisc = {
-    offsetof(item, p),
-    sizeof(2 * sizeof(void *)),
-    offsetof(item, link),
-    (Dtmake_f) newItem,
-    (Dtfree_f) freeItem,
-    (Dtcompar_f) cmpItem,
-    NIL(Dthash_f),
-    NIL(Dtmemory_f),
-    NIL(Dtevent_f)
+    .key = offsetof(item, p),
+    .size = sizeof(2 * sizeof(void *)),
+    .link = offsetof(item, link),
+    .makef = (Dtmake_f)newItem,
+    .freef = (Dtfree_f)freeItem,
+    .comparf = (Dtcompar_f)cmpItem,
 };
 
 /* cloneEdge:
@@ -1023,7 +1004,7 @@ static edge_t *cloneEdge(edge_t * e, node_t * ct, node_t * ch)
 {
     graph_t *g = agraphof(ct);
     edge_t *ce = agedge(g, ct, ch,NULL,1);
-    agbindrec(ce, "Agedgeinfo_t", sizeof(Agedgeinfo_t), TRUE);
+    agbindrec(ce, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);
     agcopyattr(e, ce);
     ED_compound(ce) = TRUE;
 
@@ -1179,11 +1160,11 @@ void processClusterEdges(graph_t * g)
     agxbuf xb;
     Dt_t *map;
     Dt_t *cmap = mkClustMap (g);
-    unsigned char buf[SMALLBUF];
+    char buf[SMALLBUF];
 
     map = dtopen(&mapDisc, Dtoset);
     clg = agsubg(g, "__clusternodes",1);
-    agbindrec(clg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+    agbindrec(clg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
     agxbinit(&xb, SMALLBUF, buf);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	if (IS_CLUST_NODE(n)) continue;
@@ -1200,7 +1181,7 @@ void processClusterEdges(graph_t * g)
     agclose(clg);
     if (num_cl_edges) {
 	cl_edge_t* cl_info;
-	cl_info = agbindrec(g, CL_EDGE_TAG, sizeof(cl_edge_t), FALSE);
+	cl_info = agbindrec(g, CL_EDGE_TAG, sizeof(cl_edge_t), false);
 	cl_info->n_cluster_edges = num_cl_edges;
     }
     dtclose(cmap);
@@ -1230,7 +1211,7 @@ static node_t *mapN(node_t * n, graph_t * clg)
     if ((nn = agfindnode(g, name)))
 	return nn;
     nn = agnode(g, name, 1);
-    agbindrec(nn, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);
+    agbindrec(nn, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);
     SET_CLUST_NODE(nn);
 
     /* Set all attributes to default */
@@ -1284,7 +1265,7 @@ void undoClusterEdges(graph_t * g)
 
     if (!ecnt) return;
     clg = agsubg(g, "__clusternodes",1);
-    agbindrec(clg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+    agbindrec(clg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
     elist = N_NEW(ecnt, edge_t*);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
@@ -1381,14 +1362,14 @@ htmlEntity (char** s)
                     byte = byte - '0';
 		else
                     break;
-		n = (n * 16) + byte;
+		n = (n * 16) + (int)byte;
 	    }
 	}
 	else {
 	    for (i = 1; i < 8; i++) {
 		byte = *(str + i);
 		if (byte >= '0' && byte <= '9')
-		    n = (n * 10) + (byte - '0');
+		    n = (n * 10) + ((int)byte - '0');
 		else
 		    break;
 	    }
@@ -1415,7 +1396,7 @@ htmlEntity (char** s)
 		}
 		break;
 	    }
-	    *p++ = byte;
+	    *p++ = (char)byte;
 	}
     }
     *s = (char*)str;
@@ -1450,7 +1431,7 @@ cvtAndAppend (unsigned char c, agxbuf* xb)
 char* htmlEntityUTF8 (char* s, graph_t* g)
 {
     static graph_t* lastg;
-    static boolean warned;
+    static bool warned;
     char*  ns;
     agxbuf xb;
     unsigned char c;
@@ -1461,7 +1442,7 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
 
     if (lastg != g) {
 	lastg = g;
-	warned = 0;
+	warned = false;
     }
 
     agxbinit(&xb, 0, NULL);
@@ -1485,7 +1466,7 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
             uc = -1;
             if (!warned) {
                 agerr(AGWARN, "UTF8 codes > 4 bytes are not currently supported (graph %s) - treated as Latin-1. Perhaps \"-Gcharset=latin1\" is needed?\n", agnameof(g));
-                warned = 1;
+                warned = true;
             }
             c = cvtAndAppend (c, &xb);
         }
@@ -1517,7 +1498,7 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
                 else {
 		            if (!warned) {
 		                agerr(AGWARN, "Invalid %d-byte UTF8 found in input of graph %s - treated as Latin-1. Perhaps \"-Gcharset=latin1\" is needed?\n", uc + 1, agnameof(g));
-		                warned = 1;
+		                warned = true;
 		            }
 		            c = cvtAndAppend (c, &xb);
                     break;
@@ -1597,13 +1578,13 @@ utf8ToLatin1 (char* s)
     return ns;
 }
 
-boolean overlap_node(node_t *n, boxf b)
+bool overlap_node(node_t *n, boxf b)
 {
     inside_t ictxt;
     pointf p;
 
     if (! OVERLAP(b, ND_bb(n)))
-        return FALSE;
+        return false;
 
 /*  FIXME - need to do something better about CLOSEENOUGH */
     p = sub_pointf(ND_coord(n), mid_pointf(b.UR, b.LL));
@@ -1614,7 +1595,7 @@ boolean overlap_node(node_t *n, boxf b)
     return ND_shape(n)->fns->insidefn(&ictxt, p);
 }
 
-boolean overlap_label(textlabel_t *lp, boxf b)
+bool overlap_label(textlabel_t *lp, boxf b)
 {
     pointf s;
     boxf bb;
@@ -1626,16 +1607,13 @@ boolean overlap_label(textlabel_t *lp, boxf b)
     return OVERLAP(b, bb);
 }
 
-static boolean overlap_arrow(pointf p, pointf u, double scale, int flag, boxf b)
+static bool overlap_arrow(pointf p, pointf u, double scale, boxf b)
 {
-    if (OVERLAP(b, arrow_bb(p, u, scale, flag))) {
-	/* FIXME - check inside arrow shape */
-	return TRUE;
-    }
-    return FALSE;
+    // FIXME - check inside arrow shape
+    return OVERLAP(b, arrow_bb(p, u, scale));
 }
 
-static boolean overlap_bezier(bezier bz, boxf b)
+static bool overlap_bezier(bezier bz, boxf b)
 {
     int i;
     pointf p, u;
@@ -1645,23 +1623,23 @@ static boolean overlap_bezier(bezier bz, boxf b)
     for (i = 1; i < bz.size; i++) {
 	p = bz.list[i];
 	if (lineToBox(p, u, b) != -1)
-	    return TRUE;
+	    return true;
 	u = p;
     }
 
     /* check arrows */
     if (bz.sflag) {
-	if (overlap_arrow(bz.sp, bz.list[0], 1, bz.sflag, b))
-	    return TRUE;
+	if (overlap_arrow(bz.sp, bz.list[0], 1, b))
+	    return true;
     }
     if (bz.eflag) {
-	if (overlap_arrow(bz.ep, bz.list[bz.size - 1], 1, bz.eflag, b))
-	    return TRUE;
+	if (overlap_arrow(bz.ep, bz.list[bz.size - 1], 1, b))
+	    return true;
     }
-    return FALSE;
+    return false;
 }
 
-boolean overlap_edge(edge_t *e, boxf b)
+bool overlap_edge(edge_t *e, boxf b)
 {
     int i;
     splines *spl;
@@ -1671,13 +1649,13 @@ boolean overlap_edge(edge_t *e, boxf b)
     if (spl && boxf_overlap(spl->bb, b))
         for (i = 0; i < spl->size; i++)
             if (overlap_bezier(spl->list[i], b))
-                return TRUE;
+                return true;
 
     lp = ED_label(e);
     if (lp && overlap_label(lp, b))
-        return TRUE;
+        return true;
 
-    return FALSE;
+    return false;
 }
 
 /* edgeType:
@@ -1690,31 +1668,31 @@ static int edgeType(const char *s, int dflt)
     }
 
     if (*s == '0') { /* false */
-	return ET_LINE;
+	return EDGETYPE_LINE;
     } else if (*s >= '1' && *s <= '9') { /* true */
-	return ET_SPLINE;
+	return EDGETYPE_SPLINE;
     } else if (strcasecmp(s, "curved") == 0) {
-	return ET_CURVED;
+	return EDGETYPE_CURVED;
     } else if (strcasecmp(s, "compound") == 0) {
-	return ET_COMPOUND;
+	return EDGETYPE_COMPOUND;
     } else if (strcasecmp(s, "false") == 0) {
-	return ET_LINE;
+	return EDGETYPE_LINE;
     } else if (strcasecmp(s, "line") == 0) {
-	return ET_LINE;
+	return EDGETYPE_LINE;
     } else if (strcasecmp(s, "none") == 0) {
-	return ET_NONE;
+	return EDGETYPE_NONE;
     } else if (strcasecmp(s, "no") == 0) {
-	return ET_LINE;
+	return EDGETYPE_LINE;
     } else if (strcasecmp(s, "ortho") == 0) {
-	return ET_ORTHO;
+	return EDGETYPE_ORTHO;
     } else if (strcasecmp(s, "polyline") == 0) {
-	return ET_PLINE;
+	return EDGETYPE_PLINE;
     } else if (strcasecmp(s, "spline") == 0) {
-	return ET_SPLINE;
+	return EDGETYPE_SPLINE;
     } else if (strcasecmp(s, "true") == 0) {
-	return ET_SPLINE;
+	return EDGETYPE_SPLINE;
     } else if (strcasecmp(s, "yes") == 0) {
-	return ET_SPLINE;
+	return EDGETYPE_SPLINE;
     }
 
     agerr(AGWARN, "Unknown \"splines\" value: \"%s\" - ignored\n", s);
@@ -1726,12 +1704,12 @@ static int edgeType(const char *s, int dflt)
  * If the attribute is not defined, use default.
  * If the attribute is "", use NONE.
  * If attribute value matches (case indepedent), use match.
- *   ortho => ET_ORTHO
- *   none => ET_NONE
- *   line => ET_LINE
- *   polyline => ET_PLINE
- *   spline => ET_SPLINE
- * If attribute is boolean, true means ET_SPLINE, false means ET_LINE.
+ *   ortho => EDGETYPE_ORTHO
+ *   none => EDGETYPE_NONE
+ *   line => EDGETYPE_LINE
+ *   polyline => EDGETYPE_PLINE
+ *   spline => EDGETYPE_SPLINE
+ * If attribute is boolean, true means EDGETYPE_SPLINE, false means EDGETYPE_LINE.
  * Else warn and use default.
  */
 void setEdgeType (graph_t* g, int dflt)
@@ -1743,7 +1721,7 @@ void setEdgeType (graph_t* g, int dflt)
 	et = dflt;
     }
     else if (*s == '\0') {
-	et = ET_NONE;
+	et = EDGETYPE_NONE;
     }
     else et = edgeType (s, dflt);
     GD_flags(g) |= et;
@@ -1759,8 +1737,7 @@ void setEdgeType (graph_t* g, int dflt)
  * By default, this assumes a left-hand coordinate system (for svg); if RHS = 2 flag
  * is set, use standard coordinate system.
  */
-void get_gradient_points(pointf * A, pointf * G, int n, float angle, int flags)
-{
+void get_gradient_points(pointf *A, pointf *G, int n, double angle, int flags) {
     int i;
     double rx, ry;
     pointf min,max,center;
@@ -1789,8 +1766,7 @@ void get_gradient_points(pointf * A, pointf * G, int n, float angle, int flags)
       center.y = min.y + (max.y - min.y)/2;
     if (isRadial) {
 	double inner_r, outer_r;
-	outer_r = sqrt((center.x - min.x)*(center.x - min.x) +
-		      (center.y - min.y)*(center.y - min.y));
+	outer_r = hypot(center.x - min.x, center.y - min.y);
 	inner_r = outer_r /4.;
 	if (isRHS) {
 	    G[0].y = center.y;
@@ -1855,7 +1831,7 @@ void gv_cleanup_node(node_t * n)
 	agdelrec(n, "Agnodeinfo_t");
 }
 
-void gv_nodesize(node_t * n, boolean flip)
+void gv_nodesize(node_t * n, bool flip)
 {
     double w;
 
@@ -1872,7 +1848,6 @@ void gv_nodesize(node_t * n, boolean flip)
 }
 
 #ifndef HAVE_DRAND48
-#pragma weak drand48
 double drand48(void)
 {
     double d;
@@ -1889,19 +1864,16 @@ typedef struct {
 
 static void free_clust (Dt_t* dt, clust_t* clp, Dtdisc_t* disc)
 {
+    (void)dt;
+    (void)disc;
     free (clp);
 }
 
 static Dtdisc_t strDisc = {
-    offsetof(clust_t,name),
-    -1,
-    offsetof(clust_t,link),
-    NIL(Dtmake_f),
-    (Dtfree_f)free_clust,
-    NIL(Dtcompar_f),
-    NIL(Dthash_f),
-    NIL(Dtmemory_f),
-    NIL(Dtevent_f)
+    .key = offsetof(clust_t, name),
+    .size = -1,
+    .link = offsetof(clust_t, link),
+    .freef = (Dtfree_f)free_clust,
 };
 
 static void fillMap (Agraph_t* g, Dt_t* map)
