@@ -57,7 +57,7 @@ Agraph_t *sameG(void *p1, void *p2, char *fn, char *msg)
 int indexOf(char *s1, char *s2)
 {
     char *s = strstr(s1, s2);
-    return s == NULL ? -1 : (int)(s1 - s);
+    return s == NULL ? -1 : (int)(s - s1);
 }
 
 /* rindexOf:
@@ -281,15 +281,10 @@ static int cmppair(Dt_t * d, Agedge_t** key1, Agedge_t** key2, Dtdisc_t * disc)
 }
 
 static Dtdisc_t edgepair = {
-    offsetof(edgepair_t, key),
-    sizeof(Agedge_t*),
-    offsetof(edgepair_t, link),
-    NIL(Dtmake_f),
-    NIL(Dtfree_f),
-    (Dtcompar_f) cmppair,
-    NIL(Dthash_f),
-    NIL(Dtmemory_f),
-    NIL(Dtevent_f)
+    .key = offsetof(edgepair_t, key),
+    .size = sizeof(Agedge_t *),
+    .link = offsetof(edgepair_t, link),
+    .comparf = (Dtcompar_f)cmppair,
 };
 
 /* cloneGraph:
@@ -657,7 +652,7 @@ Agraph_t *freadFile(Expr_t * ex, int fd)
     return readG(sp);
 }
 
-int openFile(Expr_t * ex, char *fname, char *mode)
+int openFile(Expr_t * ex, const char *fname, const char *mode)
 {
     int idx;
 
@@ -998,9 +993,9 @@ static char* resolveColor (char* str)
     char* ss;   /* second slash */
     char* c2;   /* second char */
 
-    if ((*str == 'b') || !strncmp(str+1,"lack",4)) return str;
-    if ((*str == 'w') || !strncmp(str+1,"hite",4)) return str;
-    if ((*str == 'l') || !strncmp(str+1,"ightgrey",8)) return str;
+    if (strncmp(str, "black", strlen("black")) == 0) return str;
+    if (strncmp(str, "white", strlen("white")) == 0) return str;
+    if (strncmp(str, "lightgrey", strlen("lightgrey")) == 0) return str;
     if (*str == '/') {   /* if begins with '/' */
 	c2 = str+1;
         if ((ss = strchr(c2, '/'))) {  /* if has second '/' */
@@ -1282,6 +1277,7 @@ char *colorx (Expr_t* ex, char* incolor, char* fmt, Sfio_t* fp)
     }
     else if (*fmt == 'C') {
 	type = CMYK_BYTE;
+	alpha = 0;
     }
     else
 	return "";
