@@ -42,13 +42,6 @@ void SplitNode(RTree_t * rtp, Node_t * n, Branch_t * b, Node_t ** nn)
     PrintBranch(-1, b);
 #endif
 
-    if (rtp->StatFlag) {
-	if (rtp->Deleting)
-	    rtp->DeSplitCount++;
-	else
-	    rtp->InSplitCount++;
-    }
-
     /* load all the branches into a buffer, initialize old node */
     int level = n->level;
     GetBranches(rtp, n, b);
@@ -67,14 +60,8 @@ void SplitNode(RTree_t * rtp, Node_t * n, Branch_t * b, Node_t ** nn)
     struct PartitionVars *p = &rtp->split.Partitions[0];
     MethodZero(rtp);
 
-    int area = RectArea(&p->cover[0]) + RectArea(&p->cover[1]);
-
-    /* record how good the split was for statistics */
-    if (rtp->StatFlag && !rtp->Deleting && area)
-	rtp->SplitMeritSum += (float) rtp->split.CoverSplitArea / area;
-
     /* put branches from buffer into 2 nodes according to chosen partition */
-    *nn = RTreeNewNode(rtp);
+    *nn = RTreeNewNode();
     (*nn)->level = n->level = level;
     LoadNodes(rtp, n, *nn, p);
     assert(n->count + (*nn)->count == NODECARD + 1);
