@@ -8,6 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include	<assert.h>
 #include	<sfio/sfhdr.h>
 #include	<stddef.h>
 
@@ -35,10 +36,10 @@ int sfclose(Sfio_t * f)
     while (f->push) {
 	Sfio_t *pop;
 
-	if (!(pop = (*_Sfstack) (f, NULL)))
+	if (!(pop = _Sfstack(f, NULL)))
 	    SFMTXRETURN(f, -1);
 	if (sfclose(pop) < 0) {
-	    (*_Sfstack) (f, pop);
+	    _Sfstack(f, pop);
 	    SFMTXRETURN(f, -1);
 	}
     }
@@ -74,8 +75,8 @@ int sfclose(Sfio_t * f)
 	    }
 	} else {
 	    f->mode &= ~SF_LOCK;
-	    /**/ ASSERT(_Sfpmove);
-	    if ((*_Sfpmove) (f, -1) < 0) {
+	    assert(_Sfpmove);
+	    if (_Sfpmove(f, -1) < 0) {
 		SFOPEN(f, 0);
 		SFMTXRETURN(f, -1);
 	    }
@@ -86,7 +87,7 @@ int sfclose(Sfio_t * f)
 
     if (f->data && (!local || (f->flags & SF_STRING) || (f->bits & SF_MMAP))) {	/* free buffer */
 	if (f->flags & SF_MALLOC)
-	    data = (void *) f->data;
+	    data = f->data;
 
 	f->data = NULL;
 	f->size = -1;
