@@ -8,12 +8,12 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef _SFHDR_H
-#define _SFHDR_H	1
 #if !defined(_BLD_sfio)
 #define _BLD_sfio	1
 #endif
@@ -48,27 +48,15 @@ extern "C" {
 
 #ifdef HAVE_SYS_STAT_H
 #	include	<sys/stat.h>
-#	undef HAVE_SYS_STAT_H
-#	define HAVE_SYS_STAT_H 1
-#else
-#	ifdef HAVE_STAT_H
-#		include	<stat.h>
-#		define	HAVE_SYS_STAT_H	1
-#	endif
 #endif /*HAVE_SYS_STAT_H*/
 
 #include	<fcntl.h>
 
-#ifdef HAVE_UNISTD_H
 #include	<unistd.h>
-#endif
 
 #include	<errno.h>
 #include	<ctype.h>
 
-#undef SF_MTSAFE		/* no need to worry about thread-safety */
-#define SF_MTSAFE		0
-
 #define SFMTXSTART(f,v)		{ if(!f) return(v); }
 #define SFMTXRETURN(f,v)	{ return(v); }
 
@@ -85,9 +73,6 @@ extern "C" {
 #endif
 #endif
 
-/* to get rid of pesky compiler warnings */
-#define NOTUSED(x)	(void)(x)
-
 /* Private flags in the "bits" field */
 #define SF_MMAP		00000001	/* in memory mapping mode               */
 #define SF_BOTH		00000002	/* both read/write                      */
@@ -115,14 +100,7 @@ extern "C" {
 #define SF_AVAIL	00020000u	/* was closed, available for reuse      */
 #define SF_LOCAL	00100000u	/* sentinel for a local call            */
 
-#ifdef DEBUG
-#define ASSERT(p)	((p) ? 0 : (abort(),0) )
-#else
-#define ASSERT(p)
-#endif
-
 /* short-hands */
-#define NIL(t)		((t)0)
 #ifndef uchar
 #define uchar		unsigned char
 #endif
@@ -151,9 +129,6 @@ extern "C" {
 #ifndef S_IFCHR
 #define S_IFCHR	0
 #endif
-#ifndef S_IFIFO
-#define S_IFIFO	0
-#endif
 
 #ifndef S_ISDIR
 #define S_ISDIR(m)	(((m)&S_IFMT) == S_IFDIR)
@@ -165,14 +140,6 @@ extern "C" {
 #define S_ISCHR(m)	(((m)&S_IFMT) == S_IFCHR)
 #endif
 
-#ifndef S_ISFIFO
-#	ifdef S_IFIFO
-#		define S_ISFIFO(m)	(((m)&S_IFMT) == S_IFIFO)
-#	else
-#		define S_ISFIFO(m)	(0)
-#	endif
-#endif
-
 #if defined(S_IRUSR) && defined(S_IWUSR) && defined(S_IRGRP) && defined(S_IWGRP) && defined(S_IROTH) && defined(S_IWOTH)
 #define SF_CREATMODE	(S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH)
 #else
@@ -193,9 +160,6 @@ extern "C" {
 #define EINVAL	22
 #endif
 /* function to get the decimal point for local environment */
-#ifdef MAXFLOAT			/* we don't need these, so we zap them to avoid compiler warnings */
-#undef MAXFLOAT
-#endif
 #include	<locale.h>
 #define SFSETLOCALE(decimal,thousand) \
 	{ struct lconv*	lv; \
@@ -393,8 +357,8 @@ extern "C" {
 /* lock/open a stream */
 #define SFMODE(f,l)	((f)->mode & ~(SF_RV|SF_RC|((l) ? SF_LOCK : 0)) )
 #define SFLOCK(f,l)	(void)((f)->mode |= SF_LOCK, (f)->endr = (f)->endw = (f)->data)
-#define _SFOPENRD(f)	((f)->endr = ((f)->flags&SF_MTSAFE) ? (f)->data : (f)->endb)
-#define _SFOPENWR(f)	((f)->endw = ((f)->flags&(SF_MTSAFE|SF_LINE)) ? (f)->data : (f)->endb)
+#define _SFOPENRD(f)	((f)->endr = (f)->endb)
+#define _SFOPENWR(f)	((f)->endw = ((f)->flags&SF_LINE) ? (f)->data : (f)->endb)
 #define _SFOPEN(f)	((f)->mode == SF_READ  ? _SFOPENRD(f) : \
 			 (f)->mode == SF_WRITE ? _SFOPENWR(f) : \
 			 ((f)->endw = (f)->endr = (f)->data) )
@@ -477,17 +441,9 @@ extern "C" {
 #ifndef O_TEXT
 #define O_TEXT		000
 #endif
-#ifndef O_TEMPORARY
-#define O_TEMPORARY	000
-#endif
 
 #define	SF_RADIX	64	/* maximum integer conversion base */
 
-#define SF_MAXINT	((int)(((uint)~0) >> 1))
-#define SF_MAXLONG	((long)(((ulong)~0L) >> 1))
-
-#define SF_MAXCHAR	((uchar)(~0))
-
 /* floating point to ascii conversion */
 #define SF_MAXEXP10	6
 #define SF_MAXPOW10	(1 << SF_MAXEXP10)
@@ -516,9 +472,9 @@ extern "C" {
 	int sf_cvinit;		/* initialization state         */
 	Fmtpos_t *(*sf_fmtposf) (Sfio_t *, const char *, va_list, int);
 	char *(*sf_fmtintf) (const char *, int *);
-	uchar sf_cv36[SF_MAXCHAR + 1];	/* conversion for base [2-36]   */
-	uchar sf_cv64[SF_MAXCHAR + 1];	/* conversion for base [37-64]  */
-	uchar sf_type[SF_MAXCHAR + 1];	/* conversion formats&types     */
+	uchar sf_cv36[UCHAR_MAX + 1];	/* conversion for base [2-36]   */
+	uchar sf_cv64[UCHAR_MAX + 1];	/* conversion for base [37-64]  */
+	uchar sf_type[UCHAR_MAX + 1];	/* conversion formats&types     */
     } Sftab_t;
 
 /* thread-safe macro/function to initialize _Sfcv* conversion tables */
@@ -594,35 +550,14 @@ extern "C" {
     extern Sfrsrv_t *_sfrsrv(Sfio_t *, ssize_t);
     extern int _sfsetpool(Sfio_t *);
     extern char *_sfcvt(void *, int, int *, int *, int);
-    extern char **_sfgetpath(char *);
 
 #ifdef _WIN32
 #undef SF_ERROR
 #include <io.h>
 #define SF_ERROR	0000400	/* an error happened                    */
 #else
-#ifndef HAVE_UNISTD_H
-    extern int close(int);
-    extern ssize_t read(int, void *, size_t);
-    extern ssize_t write(int, const void *, size_t);
-    extern off_t lseek(int, off_t, int);
-    extern int dup(int);
-    extern int isatty(int);
-    extern int wait(int *);
-    extern int pipe(int *);
-    extern int access(const char *, int);
-    extern uint sleep(uint);
-    extern int execl(const char *, const char *, ...);
-    extern int execv(const char *, char **);
-
-#endif /*HAVE_UNISTD_H*/
 #endif /* _WIN32 */
 
-#ifdef HAVE_SYS_STAT_H
-    extern int fstat(int, Stat_t *);
-#endif
-
-#endif /*_SFHDR_H*/
 #ifdef __cplusplus
 }
 #endif
