@@ -8,13 +8,12 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef _SFIO_H
-#define _SFIO_H	1
-
 /*	Public header file for the sfio library
 **
 **	Written by Kiem-Phong Vo
@@ -137,7 +136,6 @@ extern "C" {
 #define SF_STATIC	0001000	/* a stream that cannot be freed        */
 #define SF_IOCHECK	0002000	/* call exceptf before doing IO         */
 #define SF_PUBLIC	0004000	/* SF_SHARE and follow physical seek    */
-#define SF_MTSAFE	0010000	/* need thread safety                   */
 #define SF_WHOLE	0020000	/* preserve wholeness of sfwrite/sfputr */
 
 #define SF_FLAGS	0077177	/* PUBLIC FLAGS PASSABLE TO SFNEW()     */
@@ -178,18 +176,18 @@ extern "C" {
      extern ssize_t _Sfi;
 
 #if defined(_BLD_sfio) && defined(GVDLL)
-#define EXTERN	__declspec(dllexport)
+#define SFIO_API	__declspec(dllexport)
 #else
-#define EXTERN /* nothing */
+#define SFIO_API /* nothing */
 #endif
 /* standard in/out/err streams */
-    EXTERN extern Sfio_t *sfstdin;
-    EXTERN extern Sfio_t *sfstdout;
-    EXTERN extern Sfio_t *sfstderr;
-    EXTERN extern Sfio_t _Sfstdin;
-    EXTERN extern Sfio_t _Sfstdout;
-    EXTERN extern Sfio_t _Sfstderr;
-#undef EXTERN
+    SFIO_API extern Sfio_t *sfstdin;
+    SFIO_API extern Sfio_t *sfstdout;
+    SFIO_API extern Sfio_t *sfstderr;
+    SFIO_API extern Sfio_t _Sfstdin;
+    SFIO_API extern Sfio_t _Sfstdout;
+    SFIO_API extern Sfio_t _Sfstderr;
+#undef SFIO_API
 
 
     extern Sfio_t *sfnew(Sfio_t *, void *, size_t, int, int);
@@ -214,7 +212,6 @@ extern "C" {
     extern int sfsscanf(const char *, const char *, ...);
     extern int sfvsscanf(const char *, const char *, va_list);
     extern int sfvscanf(Sfio_t *, const char *, va_list);
-    extern int sfresize(Sfio_t *, Sfoff_t);
 
 /* io functions with discipline continuation */
     extern ssize_t sfrd(Sfio_t *, void *, size_t, Sfdisc_t *);
@@ -253,7 +250,6 @@ extern "C" {
 #define sfgetc(f)				( __sf_getc(f)			)
 #define sffileno(f)				( __sf_fileno(f)		)
 #define sfslen()				( __sf_slen()			)
-#endif				/* _SFIO_H */
 #ifdef __cplusplus
 }
 #endif
