@@ -19,15 +19,16 @@
 #include <sparse/SparseMatrix.h>
 #include <sparse/BinaryHeap.h>
 #include <stddef.h>
+#include <stdbool.h>
 
 static size_t size_of_matrix_type(int type){
   size_t size = 0;
   switch (type){
   case MATRIX_TYPE_REAL:
-    size = sizeof(real);
+    size = sizeof(double);
     break;
   case MATRIX_TYPE_COMPLEX:
-    size = 2*sizeof(real);
+    size = 2*sizeof(double);
     break;
   case MATRIX_TYPE_INTEGER:
     size = sizeof(int);
@@ -57,7 +58,7 @@ SparseMatrix SparseMatrix_sort(SparseMatrix A){
 SparseMatrix SparseMatrix_make_undirected(SparseMatrix A){
   /* make it strictly low diag only, and set flag to undirected */
   SparseMatrix B;
-  B = SparseMatrix_symmetrize(A, FALSE);
+  B = SparseMatrix_symmetrize(A, false);
   SparseMatrix_set_undirected(B);
   return SparseMatrix_remove_upper(B);
 }
@@ -86,8 +87,8 @@ SparseMatrix SparseMatrix_transpose(SparseMatrix A){
 
   switch (A->type){
   case MATRIX_TYPE_REAL:{
-    real *a = (real*) A->a;
-    real *b = (real*) B->a;
+    double *a = (double*) A->a;
+    double *b = (double*) B->a;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
 	jb[ib[ja[j]]] = i;
@@ -97,8 +98,8 @@ SparseMatrix SparseMatrix_transpose(SparseMatrix A){
     break;
   }
   case MATRIX_TYPE_COMPLEX:{
-    real *a = (real*) A->a;
-    real *b = (real*) B->a;
+    double *a = (double*) A->a;
+    double *b = (double*) B->a;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
 	jb[ib[ja[j]]] = i;
@@ -143,7 +144,8 @@ SparseMatrix SparseMatrix_transpose(SparseMatrix A){
   return B;
 }
 
-SparseMatrix SparseMatrix_symmetrize(SparseMatrix A, int pattern_symmetric_only){
+SparseMatrix SparseMatrix_symmetrize(SparseMatrix A,
+                                     bool pattern_symmetric_only) {
   SparseMatrix B;
   if (SparseMatrix_is_symmetric(A, pattern_symmetric_only)) return SparseMatrix_copy(A);
   B = SparseMatrix_transpose(A);
@@ -157,7 +159,7 @@ SparseMatrix SparseMatrix_symmetrize(SparseMatrix A, int pattern_symmetric_only)
 
 SparseMatrix SparseMatrix_symmetrize_nodiag(SparseMatrix A){
   SparseMatrix B;
-  if (SparseMatrix_is_symmetric(A, FALSE)) {
+  if (SparseMatrix_is_symmetric(A, false)) {
     B = SparseMatrix_copy(A);
     return SparseMatrix_remove_diagonal(B);
   }
@@ -170,7 +172,7 @@ SparseMatrix SparseMatrix_symmetrize_nodiag(SparseMatrix A){
   return SparseMatrix_remove_diagonal(A);
 }
 
-int SparseMatrix_is_symmetric(SparseMatrix A, int test_pattern_symmetry_only){
+int SparseMatrix_is_symmetric(SparseMatrix A, bool test_pattern_symmetry_only){
   if (!A) return FALSE;
 
   /* assume no repeated entries! */
@@ -203,8 +205,8 @@ int SparseMatrix_is_symmetric(SparseMatrix A, int test_pattern_symmetry_only){
 
   switch (type){
   case MATRIX_TYPE_REAL:{
-    real *a = (real*) A->a;
-    real *b = (real*) B->a;
+    double *a = (double*) A->a;
+    double *b = (double*) B->a;
     for (i = 0; i <= m; i++) if (ia[i] != ib[i]) goto RETURN;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
@@ -221,8 +223,8 @@ int SparseMatrix_is_symmetric(SparseMatrix A, int test_pattern_symmetry_only){
     break;
   }
   case MATRIX_TYPE_COMPLEX:{
-    real *a = (real*) A->a;
-    real *b = (real*) B->a;
+    double *a = (double*) A->a;
+    double *b = (double*) B->a;
     for (i = 0; i <= m; i++) if (ia[i] != ib[i]) goto RETURN;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
@@ -282,7 +284,7 @@ int SparseMatrix_is_symmetric(SparseMatrix A, int test_pattern_symmetry_only){
     SparseMatrix_set_pattern_symmetric(A);
   }
  RETURN:
-  FREE(mask);
+  free(mask);
 
   SparseMatrix_delete(B);
   return res;
@@ -404,17 +406,15 @@ SparseMatrix SparseMatrix_general_new(int m, int n, int nz, int type, size_t sz,
 }
 
 void SparseMatrix_delete(SparseMatrix A){
-  /* return a sparse matrix skeleton with row dimension m and storage nz. If nz == 0, 
-     only row pointers are allocated */
   if (!A) return;
-  if (A->ia) FREE(A->ia);
-  if (A->ja) FREE(A->ja);
-  if (A->a) FREE(A->a);
-  FREE(A);
+  free(A->ia);
+  free(A->ja);
+  free(A->a);
+  free(A);
 }
 static void SparseMatrix_print_csr(char *c, SparseMatrix A){
   int *ia, *ja;
-  real *a;
+  double *a;
   int *ai;
   int i, j, m = A->m;
   
@@ -425,7 +425,7 @@ static void SparseMatrix_print_csr(char *c, SparseMatrix A){
   a = A->a;
   switch (A->type){
   case MATRIX_TYPE_REAL:
-    a = (real*) A->a;
+    a = (double*) A->a;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
 	printf("{%d, %d}->%f",i+1, ja[j]+1, a[j]);
@@ -434,7 +434,7 @@ static void SparseMatrix_print_csr(char *c, SparseMatrix A){
     }
     break;
   case MATRIX_TYPE_COMPLEX:
-    a = (real*) A->a;
+    a = (double*) A->a;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
 	printf("{%d, %d}->%f + %f I",i+1, ja[j]+1, a[2*j], a[2*j+1]);
@@ -475,7 +475,7 @@ static void SparseMatrix_print_csr(char *c, SparseMatrix A){
 
 static void SparseMatrix_print_coord(char *c, SparseMatrix A){
   int *ia, *ja;
-  real *a;
+  double *a;
   int *ai;
   int i, m = A->m;
   
@@ -486,7 +486,7 @@ static void SparseMatrix_print_coord(char *c, SparseMatrix A){
   a = A->a;
   switch (A->type){
   case MATRIX_TYPE_REAL:
-    a = (real*) A->a;
+    a = (double*) A->a;
     for (i = 0; i < A->nz; i++){
       printf("{%d, %d}->%f",ia[i]+1, ja[i]+1, a[i]);
       if (i != A->nz - 1) printf(",");
@@ -494,7 +494,7 @@ static void SparseMatrix_print_coord(char *c, SparseMatrix A){
     printf("\n");
     break;
   case MATRIX_TYPE_COMPLEX:
-    a = (real*) A->a;
+    a = (double*) A->a;
     for (i = 0; i < A->nz; i++){
       printf("{%d, %d}->%f + %f I",ia[i]+1, ja[i]+1, a[2*i], a[2*i+1]);
       if (i != A->nz - 1) printf(",");
@@ -551,7 +551,7 @@ void SparseMatrix_print(char *c, SparseMatrix A){
 
 static void SparseMatrix_export_csr(FILE *f, SparseMatrix A){
   int *ia, *ja;
-  real *a;
+  double *a;
   int *ai;
   int i, j, m = A->m;
   
@@ -580,7 +580,7 @@ static void SparseMatrix_export_csr(FILE *f, SparseMatrix A){
   a = A->a;
   switch (A->type){
   case MATRIX_TYPE_REAL:
-    a = (real*) A->a;
+    a = (double*) A->a;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
 	fprintf(f, "%d %d %16.8g\n",i+1, ja[j]+1, a[j]);
@@ -588,7 +588,7 @@ static void SparseMatrix_export_csr(FILE *f, SparseMatrix A){
     }
     break;
   case MATRIX_TYPE_COMPLEX:
-    a = (real*) A->a;
+    a = (double*) A->a;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
 	fprintf(f, "%d %d %16.8g %16.8g\n",i+1, ja[j]+1, a[2*j], a[2*j+1]);
@@ -620,7 +620,7 @@ static void SparseMatrix_export_csr(FILE *f, SparseMatrix A){
 
 static void SparseMatrix_export_coord(FILE *f, SparseMatrix A){
   int *ia, *ja;
-  real *a;
+  double *a;
   int *ai;
   int i;
   
@@ -649,13 +649,13 @@ static void SparseMatrix_export_coord(FILE *f, SparseMatrix A){
   a = A->a;
   switch (A->type){
   case MATRIX_TYPE_REAL:
-    a = (real*) A->a;
+    a = (double*) A->a;
     for (i = 0; i < A->nz; i++){
       fprintf(f, "%d %d %16.8g\n",ia[i]+1, ja[i]+1, a[i]);
     }
     break;
   case MATRIX_TYPE_COMPLEX:
-    a = (real*) A->a;
+    a = (double*) A->a;
     for (i = 0; i < A->nz; i++){
       fprintf(f, "%d %d %16.8g %16.8g\n",ia[i]+1, ja[i]+1, a[2*i], a[2*i+1]);
     }
@@ -740,7 +740,7 @@ static SparseMatrix SparseMatrix_from_coordinate_arrays_internal(int nz, int m,
 
   SparseMatrix A = NULL;
   int *ia, *ja;
-  real *a, *val;
+  double *a, *val;
   int *ai, *vali;
   int i;
 
@@ -759,8 +759,8 @@ static SparseMatrix SparseMatrix_from_coordinate_arrays_internal(int nz, int m,
 
   switch (type){
   case MATRIX_TYPE_REAL:
-    val = (real*) val0;
-    a = (real*) A->a;
+    val = (double*) val0;
+    a = (double*) A->a;
     for (i = 0; i < nz; i++){
       if (irn[i] < 0 || irn[i] >= m || jcn[i] < 0 || jcn[i] >= n) {
 	assert(0);
@@ -777,8 +777,8 @@ static SparseMatrix SparseMatrix_from_coordinate_arrays_internal(int nz, int m,
     ia[0] = 0;
     break;
   case MATRIX_TYPE_COMPLEX:
-    val = (real*) val0;
-    a = (real*) A->a;
+    val = (double*) val0;
+    a = (double*) A->a;
     for (i = 0; i < nz; i++){
       if (irn[i] < 0 || irn[i] >= m || jcn[i] < 0 || jcn[i] >= n) {
 	assert(0);
@@ -896,9 +896,9 @@ SparseMatrix SparseMatrix_add(SparseMatrix A, SparseMatrix B){
   ic[0] = 0;
   switch (A->type){
   case MATRIX_TYPE_REAL:{
-    real *a = (real*) A->a;
-    real *b = (real*) B->a;
-    real *c = (real*) C->a;
+    double *a = (double*) A->a;
+    double *b = (double*) B->a;
+    double *c = (double*) C->a;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
 	mask[ja[j]] = nz;
@@ -919,9 +919,9 @@ SparseMatrix SparseMatrix_add(SparseMatrix A, SparseMatrix B){
     break;
   }
   case MATRIX_TYPE_COMPLEX:{
-    real *a = (real*) A->a;
-    real *b = (real*) B->a;
-    real *c = (real*) C->a;
+    double *a = (double*) A->a;
+    double *b = (double*) B->a;
+    double *c = (double*) C->a;
     for (i = 0; i < m; i++){
       for (j = ia[i]; j < ia[i+1]; j++){
 	mask[ja[j]] = nz;
@@ -994,26 +994,26 @@ SparseMatrix SparseMatrix_add(SparseMatrix A, SparseMatrix B){
   C->nz = nz;
 
  RETURN:
-  if (mask) FREE(mask);
+  free(mask);
 
   return C;
 }
 
-static void SparseMatrix_multiply_dense1(SparseMatrix A, real *v, real **res, int dim){
+static void SparseMatrix_multiply_dense1(SparseMatrix A, double *v, double **res, int dim){
   /* A v where v a dense matrix of second dimension dim. Real only for now. */
   int i, j, k, *ia, *ja, m;
-  real *a, *u;
+  double *a, *u;
 
   assert(A->format == FORMAT_CSR);
   assert(A->type == MATRIX_TYPE_REAL);
 
-  a = (real*) A->a;
+  a = (double*) A->a;
   ia = A->ia;
   ja = A->ja;
   m = A->m;
   u = *res;
 
-  if (!u) u = MALLOC(sizeof(real)*((size_t) m)*((size_t) dim));
+  if (!u) u = MALLOC(sizeof(double)*((size_t) m)*((size_t) dim));
   for (i = 0; i < m; i++){
     for (k = 0; k < dim; k++) u[i*dim+k] = 0.;
     for (j = ia[i]; j < ia[i+1]; j++){
@@ -1024,17 +1024,17 @@ static void SparseMatrix_multiply_dense1(SparseMatrix A, real *v, real **res, in
   *res = u;
 }
 
-void SparseMatrix_multiply_dense(SparseMatrix A, real *v, real **res, int dim){
+void SparseMatrix_multiply_dense(SparseMatrix A, double *v, double **res, int dim){
   /* A * V, with A dimension m x n, with V of dimension n x dim. v[i*dim+j] gives V[i,j]. Result of dimension m x dim
  */
 
   SparseMatrix_multiply_dense1(A, v, res, dim);
 }
 
-void SparseMatrix_multiply_vector(SparseMatrix A, real *v, real **res, int transposed){
+void SparseMatrix_multiply_vector(SparseMatrix A, double *v, double **res) {
   /* A v or A^T v. Real only for now. */
-  int i, j, *ia, *ja, n, m;
-  real *a, *u = NULL;
+  int i, j, *ia, *ja, m;
+  double *a, *u = NULL;
   int *ai;
   assert(A->format == FORMAT_CSR);
   assert(A->type == MATRIX_TYPE_REAL || A->type == MATRIX_TYPE_INTEGER);
@@ -1042,47 +1042,26 @@ void SparseMatrix_multiply_vector(SparseMatrix A, real *v, real **res, int trans
   ia = A->ia;
   ja = A->ja;
   m = A->m;
-  n = A->n;
   u = *res;
 
   switch (A->type){
   case MATRIX_TYPE_REAL:
-    a = (real*) A->a;
+    a = (double*) A->a;
     if (v){
-      if (!transposed){
-	if (!u) u = MALLOC(sizeof(real)*((size_t)m));
-	for (i = 0; i < m; i++){
-	  u[i] = 0.;
-	  for (j = ia[i]; j < ia[i+1]; j++){
-	    u[i] += a[j]*v[ja[j]];
-	  }
-	}
-      } else {
-	if (!u) u = MALLOC(sizeof(real)*((size_t)n));
-	for (i = 0; i < n; i++) u[i] = 0.;
-	for (i = 0; i < m; i++){
-	  for (j = ia[i]; j < ia[i+1]; j++){
-	    u[ja[j]] += a[j]*v[i];
-	  }
+      if (!u) u = MALLOC(sizeof(double)*((size_t)m));
+      for (i = 0; i < m; i++){
+	u[i] = 0.;
+	for (j = ia[i]; j < ia[i+1]; j++){
+	  u[i] += a[j]*v[ja[j]];
 	}
       }
     } else {
       /* v is assumed to be all 1's */
-      if (!transposed){
-	if (!u) u = MALLOC(sizeof(real)*((size_t)m));
-	for (i = 0; i < m; i++){
-	  u[i] = 0.;
-	  for (j = ia[i]; j < ia[i+1]; j++){
-	    u[i] += a[j];
-	  }
-	}
-      } else {
-	if (!u) u = MALLOC(sizeof(real)*((size_t)n));
-	for (i = 0; i < n; i++) u[i] = 0.;
-	for (i = 0; i < m; i++){
-	  for (j = ia[i]; j < ia[i+1]; j++){
-	    u[ja[j]] += a[j];
-	  }
+      if (!u) u = MALLOC(sizeof(double)*((size_t)m));
+      for (i = 0; i < m; i++){
+	u[i] = 0.;
+	for (j = ia[i]; j < ia[i+1]; j++){
+	  u[i] += a[j];
 	}
       }
     }
@@ -1090,40 +1069,20 @@ void SparseMatrix_multiply_vector(SparseMatrix A, real *v, real **res, int trans
   case MATRIX_TYPE_INTEGER:
     ai = (int*) A->a;
     if (v){
-      if (!transposed){
-	if (!u) u = MALLOC(sizeof(real)*((size_t)m));
-	for (i = 0; i < m; i++){
-	  u[i] = 0.;
-	  for (j = ia[i]; j < ia[i+1]; j++){
-	    u[i] += ai[j]*v[ja[j]];
-	  }
-	}
-      } else {
-	if (!u) u = MALLOC(sizeof(real)*((size_t)n));
-	for (i = 0; i < n; i++) u[i] = 0.;
-	for (i = 0; i < m; i++){
-	  for (j = ia[i]; j < ia[i+1]; j++){
-	    u[ja[j]] += ai[j]*v[i];
-	  }
+      if (!u) u = MALLOC(sizeof(double)*((size_t)m));
+      for (i = 0; i < m; i++){
+	u[i] = 0.;
+	for (j = ia[i]; j < ia[i+1]; j++){
+	  u[i] += ai[j]*v[ja[j]];
 	}
       }
     } else {
       /* v is assumed to be all 1's */
-      if (!transposed){
-	if (!u) u = MALLOC(sizeof(real)*((size_t)m));
-	for (i = 0; i < m; i++){
-	  u[i] = 0.;
-	  for (j = ia[i]; j < ia[i+1]; j++){
-	    u[i] += ai[j];
-	  }
-	}
-      } else {
-	if (!u) u = MALLOC(sizeof(real)*((size_t)n));
-	for (i = 0; i < n; i++) u[i] = 0.;
-	for (i = 0; i < m; i++){
-	  for (j = ia[i]; j < ia[i+1]; j++){
-	    u[ja[j]] += ai[j];
-	  }
+      if (!u) u = MALLOC(sizeof(double)*((size_t)m));
+      for (i = 0; i < m; i++){
+	u[i] = 0.;
+	for (j = ia[i]; j < ia[i+1]; j++){
+	  u[i] += ai[j];
 	}
       }
     }
@@ -1189,9 +1148,9 @@ SparseMatrix SparseMatrix_multiply(SparseMatrix A, SparseMatrix B){
   switch (type){
   case MATRIX_TYPE_REAL:
     {
-      real *a = (real*) A->a;
-      real *b = (real*) B->a;
-      real *c = (real*) C->a;
+      double *a = (double*) A->a;
+      double *b = (double*) B->a;
+      double *c = (double*) C->a;
       ic[0] = 0;
       for (i = 0; i < m; i++){
 	for (j = ia[i]; j < ia[i+1]; j++){
@@ -1214,12 +1173,12 @@ SparseMatrix SparseMatrix_multiply(SparseMatrix A, SparseMatrix B){
     break;
   case MATRIX_TYPE_COMPLEX:
     {
-      real *a = (real*) A->a;
-      real *b = (real*) B->a;
-      real *c = (real*) C->a;
-      a = (real*) A->a;
-      b = (real*) B->a;
-      c = (real*) C->a;
+      double *a = (double*) A->a;
+      double *b = (double*) B->a;
+      double *c = (double*) C->a;
+      a = (double*) A->a;
+      b = (double*) B->a;
+      c = (double*) C->a;
       ic[0] = 0;
       for (i = 0; i < m; i++){
 	for (j = ia[i]; j < ia[i+1]; j++){
@@ -1295,9 +1254,8 @@ SparseMatrix SparseMatrix_multiply(SparseMatrix A, SparseMatrix B){
   C->nz = nz;
 
  RETURN:
-  FREE(mask);
+  free(mask);
   return C;
-
 }
 
 
@@ -1322,7 +1280,9 @@ SparseMatrix SparseMatrix_multiply3(SparseMatrix A, SparseMatrix B, SparseMatrix
     return NULL;
   }
   type = A->type;
-  
+
+  assert(type == MATRIX_TYPE_REAL);
+
   mask = MALLOC(sizeof(int)*((size_t)(C->n)));
   if (!mask) return NULL;
 
@@ -1357,134 +1317,37 @@ SparseMatrix SparseMatrix_multiply3(SparseMatrix A, SparseMatrix B, SparseMatrix
   
   nz = 0;
 
-  switch (type){
-  case MATRIX_TYPE_REAL:
-    {
-      real *a = (real*) A->a;
-      real *b = (real*) B->a;
-      real *c = (real*) C->a;
-      real *d = (real*) D->a;
-      id[0] = 0;
-      for (i = 0; i < m; i++){
-	for (j = ia[i]; j < ia[i+1]; j++){
-	  jj = ja[j];
-	  for (l = ib[jj]; l < ib[jj+1]; l++){
-	    ll = jb[l];
-	    for (k = ic[ll]; k < ic[ll+1]; k++){
-	      if (mask[jc[k]] < id[i]){
-		mask[jc[k]] = nz;
-		jd[nz] = jc[k];
-		d[nz] = a[j]*b[l]*c[k];
-		nz++;
-	      } else {
-		assert(jd[mask[jc[k]]] == jc[k]);
-		d[mask[jc[k]]] += a[j]*b[l]*c[k];
-	      }
-	    }
-	  }
-	}
-	id[i+1] = nz;
+  double *a = (double*) A->a;
+  double *b = (double*) B->a;
+  double *c = (double*) C->a;
+  double *d = (double*) D->a;
+  id[0] = 0;
+  for (i = 0; i < m; i++){
+    for (j = ia[i]; j < ia[i+1]; j++){
+      jj = ja[j];
+      for (l = ib[jj]; l < ib[jj+1]; l++){
+        ll = jb[l];
+        for (k = ic[ll]; k < ic[ll+1]; k++){
+          if (mask[jc[k]] < id[i]){
+            mask[jc[k]] = nz;
+            jd[nz] = jc[k];
+            d[nz] = a[j]*b[l]*c[k];
+            nz++;
+          } else {
+            assert(jd[mask[jc[k]]] == jc[k]);
+            d[mask[jc[k]]] += a[j]*b[l]*c[k];
+          }
+        }
       }
     }
-    break;
-  case MATRIX_TYPE_COMPLEX:
-    {
-      real *a = (real*) A->a;
-      real *b = (real*) B->a;
-      real *c = (real*) C->a;
-      real *d = (real*) D->a;
-      id[0] = 0;
-      for (i = 0; i < m; i++){
-	for (j = ia[i]; j < ia[i+1]; j++){
-	  jj = ja[j];
-	  for (l = ib[jj]; l < ib[jj+1]; l++){
-	    ll = jb[l];
-	    for (k = ic[ll]; k < ic[ll+1]; k++){
-	      if (mask[jc[k]] < id[i]){
-		mask[jc[k]] = nz;
-		jd[nz] = jc[k];
-		d[2*nz] = (a[2*j]*b[2*l] - a[2*j+1]*b[2*l+1])*c[2*k] 
-		  - (a[2*j]*b[2*l+1] + a[2*j+1]*b[2*l])*c[2*k+1];/*real part */
-		d[2*nz+1] = (a[2*j]*b[2*l+1] + a[2*j+1]*b[2*l])*c[2*k]
-		  + (a[2*j]*b[2*l] - a[2*j+1]*b[2*l+1])*c[2*k+1];/*img part */
-		nz++;
-	      } else {
-		assert(jd[mask[jc[k]]] == jc[k]);
-		d[2*mask[jc[k]]] += (a[2*j]*b[2*l] - a[2*j+1]*b[2*l+1])*c[2*k] 
-		  - (a[2*j]*b[2*l+1] + a[2*j+1]*b[2*l])*c[2*k+1];/*real part */
-		d[2*mask[jc[k]]+1] += (a[2*j]*b[2*l+1] + a[2*j+1]*b[2*l])*c[2*k]
-		  + (a[2*j]*b[2*l] - a[2*j+1]*b[2*l+1])*c[2*k+1];/*img part */
-	      }
-	    }
-	  }
-	}
-	id[i+1] = nz;
-      }
-    }
-    break;
-  case MATRIX_TYPE_INTEGER:
-    {
-      int *a = (int*) A->a;
-      int *b = (int*) B->a;
-      int *c = (int*) C->a;
-      int *d = (int*) D->a;
-      id[0] = 0;
-      for (i = 0; i < m; i++){
-	for (j = ia[i]; j < ia[i+1]; j++){
-	  jj = ja[j];
-	  for (l = ib[jj]; l < ib[jj+1]; l++){
-	    ll = jb[l];
-	    for (k = ic[ll]; k < ic[ll+1]; k++){
-	      if (mask[jc[k]] < id[i]){
-		mask[jc[k]] = nz;
-		jd[nz] = jc[k];
-		d[nz] += a[j]*b[l]*c[k];
-		nz++;
-	      } else {
-		assert(jd[mask[jc[k]]] == jc[k]);
-		d[mask[jc[k]]] += a[j]*b[l]*c[k];
-	      }
-	    }
-	  }
-	}
-	id[i+1] = nz;
-      }
-    }
-    break;
-  case MATRIX_TYPE_PATTERN:
-    id[0] = 0;
-    for (i = 0; i < m; i++){
-      for (j = ia[i]; j < ia[i+1]; j++){
-	jj = ja[j];
-	for (l = ib[jj]; l < ib[jj+1]; l++){
-	  ll = jb[l];
-	  for (k = ic[ll]; k < ic[ll+1]; k++){
-	    if (mask[jc[k]] < id[i]){
-	      mask[jc[k]] = nz;
-	      jd[nz] = jc[k];
-	      nz++;
-	    } else {
-	      assert(jd[mask[jc[k]]] == jc[k]);
-	    }
-	  }
-	}
-      }
-      id[i+1] = nz;
-    }
-    break;
-  case MATRIX_TYPE_UNKNOWN:
-  default:
-    SparseMatrix_delete(D);
-    D = NULL; goto RETURN;
-    break;
+    id[i+1] = nz;
   }
   
   D->nz = nz;
 
  RETURN:
-  FREE(mask);
+  free(mask);
   return D;
-
 }
 
 SparseMatrix SparseMatrix_sum_repeat_entries(SparseMatrix A, int what_to_sum){
@@ -1500,7 +1363,7 @@ SparseMatrix SparseMatrix_sum_repeat_entries(SparseMatrix A, int what_to_sum){
   switch (type){
   case MATRIX_TYPE_REAL:
     {
-      real *a = (real*) A->a;
+      double *a = (double*) A->a;
       nz = 0;
       sta = ia[0];
       for (i = 0; i < A->m; i++){
@@ -1521,7 +1384,7 @@ SparseMatrix SparseMatrix_sum_repeat_entries(SparseMatrix A, int what_to_sum){
     break;
   case MATRIX_TYPE_COMPLEX:
     {
-      real *a = (real*) A->a;
+      double *a = (double*) A->a;
       if (what_to_sum == SUM_REPEATED_ALL){
 	nz = 0;
 	sta = ia[0];
@@ -1591,15 +1454,17 @@ SparseMatrix SparseMatrix_sum_repeat_entries(SparseMatrix A, int what_to_sum){
     break;
   }
   A->nz = nz;
-  FREE(mask);
+  free(mask);
   return A;
 }
 
-SparseMatrix SparseMatrix_coordinate_form_add_entries(SparseMatrix A, int nentries, int *irn, int *jcn, void *val){
-  int nz, nzmax, i;
+SparseMatrix SparseMatrix_coordinate_form_add_entry(SparseMatrix A, int irn,
+                                                    int jcn, void *val) {
+  int nz, nzmax;
+
+  static const int nentries = 1;
   
   assert(A->format == FORMAT_COORD);
-  if (nentries <= 0) return A;
   nz = A->nz;
 
   if (nz + nentries >= A->nzmax){
@@ -1607,13 +1472,11 @@ SparseMatrix SparseMatrix_coordinate_form_add_entries(SparseMatrix A, int nentri
      nzmax = MAX(10, (int) 0.2*nzmax) + nzmax;
     A = SparseMatrix_realloc(A, nzmax);
   }
-  memcpy((char*) A->ia + ((size_t)nz)*sizeof(int)/sizeof(char), irn, sizeof(int)*((size_t)nentries));
-  memcpy((char*) A->ja + ((size_t)nz)*sizeof(int)/sizeof(char), jcn, sizeof(int)*((size_t)nentries));
+  A->ia[nz] = irn;
+  A->ja[nz] = jcn;
   if (A->size) memcpy((char*) A->a + ((size_t)nz)*A->size/sizeof(char), val, A->size*((size_t)nentries));
-  for (i = 0; i < nentries; i++) {
-    if (irn[i] >= A->m) A->m = irn[i]+1;
-    if (jcn[i] >= A->n) A->n = jcn[i]+1;
-  }
+  if (irn >= A->m) A->m = irn + 1;
+  if (jcn >= A->n) A->n = jcn + 1;
   A->nz += nentries;
   return A;
 }
@@ -1630,7 +1493,7 @@ SparseMatrix SparseMatrix_remove_diagonal(SparseMatrix A){
   sta = ia[0];
   switch (A->type){
   case MATRIX_TYPE_REAL:{
-    real *a = (real*) A->a;
+    double *a = (double*) A->a;
     for (i = 0; i < A->m; i++){
       for (j = sta; j < ia[i+1]; j++){
 	if (ja[j] != i){
@@ -1645,7 +1508,7 @@ SparseMatrix SparseMatrix_remove_diagonal(SparseMatrix A){
     break;
   }
   case MATRIX_TYPE_COMPLEX:{
-    real *a = (real*) A->a;
+    double *a = (double*) A->a;
     for (i = 0; i < A->m; i++){
       for (j = sta; j < ia[i+1]; j++){
 	if (ja[j] != i){
@@ -1710,7 +1573,7 @@ SparseMatrix SparseMatrix_remove_upper(SparseMatrix A){/* remove diag and upper
   sta = ia[0];
   switch (A->type){
   case MATRIX_TYPE_REAL:{
-    real *a = (real*) A->a;
+    double *a = (double*) A->a;
     for (i = 0; i < A->m; i++){
       for (j = sta; j < ia[i+1]; j++){
 	if (ja[j] < i){
@@ -1725,7 +1588,7 @@ SparseMatrix SparseMatrix_remove_upper(SparseMatrix A){/* remove diag and upper
     break;
   }
   case MATRIX_TYPE_COMPLEX:{
-    real *a = (real*) A->a;
+    double *a = (double*) A->a;
     for (i = 0; i < A->m; i++){
       for (j = sta; j < ia[i+1]; j++){
 	if (ja[j] < i){
@@ -1787,7 +1650,7 @@ SparseMatrix SparseMatrix_remove_upper(SparseMatrix A){/* remove diag and upper
 
 SparseMatrix SparseMatrix_divide_row_by_degree(SparseMatrix A){
   int i, j, *ia, *ja;
-  real deg;
+  double deg;
 
   if (!A) return A;
 
@@ -1795,7 +1658,7 @@ SparseMatrix SparseMatrix_divide_row_by_degree(SparseMatrix A){
   ja = A->ja;
   switch (A->type){
   case MATRIX_TYPE_REAL:{
-    real *a = (real*) A->a;
+    double *a = (double*) A->a;
     for (i = 0; i < A->m; i++){
       deg = ia[i+1] - ia[i];
       for (j = ia[i]; j < ia[i+1]; j++){
@@ -1805,7 +1668,7 @@ SparseMatrix SparseMatrix_divide_row_by_degree(SparseMatrix A){
     break;
   }
   case MATRIX_TYPE_COMPLEX:{
-    real *a = (real*) A->a;
+    double *a = (double*) A->a;
     for (i = 0; i < A->m; i++){
       deg = ia[i+1] - ia[i];
       for (j = ia[i]; j < ia[i+1]; j++){
@@ -1837,7 +1700,7 @@ SparseMatrix SparseMatrix_divide_row_by_degree(SparseMatrix A){
 SparseMatrix SparseMatrix_get_real_adjacency_matrix_symmetrized(SparseMatrix A){
   /* symmetric, all entries to 1, diaginal removed */
   int i, *ia, *ja, nz, m, n;
-  real *a;
+  double *a;
   SparseMatrix B;
 
   if (!A) return A;
@@ -1856,20 +1719,20 @@ SparseMatrix SparseMatrix_get_real_adjacency_matrix_symmetrized(SparseMatrix A){
   memcpy(B->ja, ja, sizeof(int)*((size_t)nz));
   B->nz = A->nz;
 
-  A = SparseMatrix_symmetrize(B, TRUE);
+  A = SparseMatrix_symmetrize(B, true);
   SparseMatrix_delete(B);
   A = SparseMatrix_remove_diagonal(A);
-  A->a = MALLOC(sizeof(real)*((size_t)(A->nz)));
-  a = (real*) A->a;
+  A->a = MALLOC(sizeof(double)*((size_t)(A->nz)));
+  a = (double*) A->a;
   for (i = 0; i < A->nz; i++) a[i] = 1.;
   A->type = MATRIX_TYPE_REAL;
-  A->size = sizeof(real);
+  A->size = sizeof(double);
   return A;
 }
 
 SparseMatrix SparseMatrix_apply_fun(SparseMatrix A, double (*fun)(double x)){
   int i, j;
-  real *a;
+  double *a;
 
 
   if (!A) return A;
@@ -1881,7 +1744,7 @@ SparseMatrix SparseMatrix_apply_fun(SparseMatrix A, double (*fun)(double x)){
   }
 
 
-  a = (real*) A->a;
+  a = (double*) A->a;
   for (i = 0; i < A->m; i++){
     for (j = A->ia[i]; j < A->ia[i+1]; j++){
       a[j] = fun(a[j]);
@@ -1984,8 +1847,8 @@ void SparseMatrix_weakly_connected_components(SparseMatrix A0, int *ncomp, int *
   int *levelset_ptr = NULL, *levelset = NULL, *mask = NULL, nlevel;
   int m = A->m, i, nn;
 
-  if (!SparseMatrix_is_symmetric(A, TRUE)){
-    A = SparseMatrix_symmetrize(A, TRUE);
+  if (!SparseMatrix_is_symmetric(A, true)){
+    A = SparseMatrix_symmetrize(A, true);
   }
   if (!(*comps_ptr)) *comps_ptr = MALLOC(sizeof(int)*((size_t)(m+1)));
 
@@ -2003,15 +1866,15 @@ void SparseMatrix_weakly_connected_components(SparseMatrix A0, int *ncomp, int *
     
   }
   if (A != A0) SparseMatrix_delete(A);
-  if (levelset_ptr) FREE(levelset_ptr);
+  free(levelset_ptr);
 
-  FREE(mask);
+  free(mask);
 }
 
 
 
 struct nodedata_struct {
-  real dist;/* distance to root */
+  double dist;/* distance to root */
   int id;/*node id */
 };
 typedef struct nodedata_struct* nodedata;
@@ -2030,7 +1893,7 @@ static int cmp(void*i, void*j){
   return 0;
 }
 
-static int Dijkstra_internal(SparseMatrix A, int root, real *dist, int *nlist, int *list, real *dist_max, int *mask){
+static int Dijkstra_internal(SparseMatrix A, int root, double *dist, int *nlist, int *list, double *dist_max, int *mask){
   /* Find the shortest path distance of all nodes to root. If khops >= 0, the shortest ath is of distance <= khops,
 
      A: the nxn connectivity matrix. Entries are assumed to be nonnegative. Absolute value will be taken if 
@@ -2047,7 +1910,7 @@ static int Dijkstra_internal(SparseMatrix A, int root, real *dist, int *nlist, i
 
   int m = A->m, i, j, jj, *ia = A->ia, *ja = A->ja, heap_id;
   BinaryHeap h;
-  real *a = NULL, *aa;
+  double *a = NULL, *aa;
   int *ai;
   nodedata ndata, ndata_min;
   enum {UNVISITED = -2, FINISHED = -1};
@@ -2055,26 +1918,26 @@ static int Dijkstra_internal(SparseMatrix A, int root, real *dist, int *nlist, i
 		   Set to FINISHED after extracted as min from heap */
   int found = 0;
 
-  assert(SparseMatrix_is_symmetric(A, TRUE));
+  assert(SparseMatrix_is_symmetric(A, true));
 
   assert(m == A->n);
 
   switch (A->type){
   case MATRIX_TYPE_COMPLEX:
-    aa = (real*) A->a;
-    a = MALLOC(sizeof(real)*((size_t)(A->nz)));
+    aa = (double*) A->a;
+    a = MALLOC(sizeof(double)*((size_t)(A->nz)));
     for (i = 0; i < A->nz; i++) a[i] = aa[i*2];
     break;
   case MATRIX_TYPE_REAL:
-    a = (real*) A->a;
+    a = (double*) A->a;
     break;
   case MATRIX_TYPE_INTEGER:
     ai = (int*) A->a;
-    a = MALLOC(sizeof(real)*((size_t)(A->nz)));
-    for (i = 0; i < A->nz; i++) a[i] = (real) ai[i];
+    a = MALLOC(sizeof(double)*((size_t)(A->nz)));
+    for (i = 0; i < A->nz; i++) a[i] = (double) ai[i];
     break;
   case MATRIX_TYPE_PATTERN:
-    a = MALLOC(sizeof(real)*((size_t)A->nz));
+    a = MALLOC(sizeof(double)*((size_t)A->nz));
     for (i = 0; i < A->nz; i++) a[i] = 1.;
     break;
   default:
@@ -2125,15 +1988,15 @@ static int Dijkstra_internal(SparseMatrix A, int root, real *dist, int *nlist, i
 	//fprintf(stderr," reset neighbor id=%d, dist=%f, hid = %d, a[%d]=%f, dist=%f\n",jj, ndata->dist,heap_id, jj, a[j], ndata->dist);
      }
     }
-    FREE(ndata_min);
+    free(ndata_min);
   }
   *nlist = found;
   *dist_max = dist[i];
 
 
-  BinaryHeap_delete(h, FREE);
-  FREE(heap_ids);
-  if (a && a != A->a) FREE(a);
+  BinaryHeap_delete(h, free);
+  free(heap_ids);
+  if (a && a != A->a) free(a);
   if (found == m || mask){
     return 0;
   } else {
@@ -2141,11 +2004,11 @@ static int Dijkstra_internal(SparseMatrix A, int root, real *dist, int *nlist, i
   }
 }
 
-static int Dijkstra(SparseMatrix A, int root, real *dist, int *nlist, int *list, real *dist_max){
+static int Dijkstra(SparseMatrix A, int root, double *dist, int *nlist, int *list, double *dist_max){
   return Dijkstra_internal(A, root, dist, nlist, list, dist_max, NULL);
 }
 
-static int Dijkstra_masked(SparseMatrix A, int root, real *dist, int *nlist, int *list, real *dist_max, int *mask){
+static int Dijkstra_masked(SparseMatrix A, int root, double *dist, int *nlist, int *list, double *dist_max, int *mask){
   /* this makes the algorithm only consider nodes that are masked.
      nodes are masked as 1, 2, ..., mask_max, which is (the number of hops from root)+1.
      Only paths consists of nodes that are masked are allowed. */
@@ -2247,9 +2110,8 @@ void SparseMatrix_decompose_to_supervariables(SparseMatrix A, int *ncluster, int
   printf("\n");
 #endif
 
-  FREE(mask);
-  FREE(super);
-
+  free(mask);
+  free(super);
 }
 
 SparseMatrix SparseMatrix_get_augmented(SparseMatrix A){
@@ -2289,11 +2151,10 @@ SparseMatrix SparseMatrix_get_augmented(SparseMatrix A){
   B = SparseMatrix_from_coordinate_arrays(nz, m + n, m + n, irn, jcn, val, type, A->size);
   SparseMatrix_set_symmetric(B);
   SparseMatrix_set_pattern_symmetric(B);
-  if (irn) FREE(irn);
-  if (jcn) FREE(jcn);
-  if (val) FREE(val);
+  free(irn);
+  free(jcn);
+  free(val);
   return B;
-
 }
 
 SparseMatrix SparseMatrix_to_square_matrix(SparseMatrix A, int bipartite_options){
@@ -2303,10 +2164,10 @@ SparseMatrix SparseMatrix_to_square_matrix(SparseMatrix A, int bipartite_options
     if (A->m == A->n) return A;
     break;
   case BIPARTITE_PATTERN_UNSYM:
-    if (A->m == A->n && SparseMatrix_is_symmetric(A, TRUE)) return A;
+    if (A->m == A->n && SparseMatrix_is_symmetric(A, true)) return A;
     break;
   case BIPARTITE_UNSYM:
-    if (A->m == A->n && SparseMatrix_is_symmetric(A, FALSE)) return A;
+    if (A->m == A->n && SparseMatrix_is_symmetric(A, false)) return A;
     break;
   case BIPARTITE_ALWAYS:
     break;
@@ -2374,11 +2235,11 @@ SparseMatrix SparseMatrix_get_submatrix(SparseMatrix A, int nrow, int ncol, int
 
   switch (A->type){
   case MATRIX_TYPE_REAL:{
-    real *a = (real*) A->a;
-    real *val;
+    double *a = (double*) A->a;
+    double *val;
     irn = MALLOC(sizeof(int)*((size_t)nz));
     jcn = MALLOC(sizeof(int)*((size_t)nz));
-    val = MALLOC(sizeof(real)*((size_t)nz));
+    val = MALLOC(sizeof(double)*((size_t)nz));
 
     nz = 0;
     for (i = 0; i < m; i++){
@@ -2394,12 +2255,12 @@ SparseMatrix SparseMatrix_get_submatrix(SparseMatrix A, int nrow, int ncol, int
     break;
   }
   case MATRIX_TYPE_COMPLEX:{
-    real *a = (real*) A->a;
-    real *val;
+    double *a = (double*) A->a;
+    double *val;
 
     irn = MALLOC(sizeof(int)*((size_t)nz));
     jcn = MALLOC(sizeof(int)*((size_t)nz));
-    val = MALLOC(sizeof(real)*2*((size_t)nz));
+    val = MALLOC(sizeof(double)*2*((size_t)nz));
 
     nz = 0;
     for (i = 0; i < m; i++){
@@ -2452,21 +2313,21 @@ SparseMatrix SparseMatrix_get_submatrix(SparseMatrix A, int nrow, int ncol, int
     }
     break;
   case MATRIX_TYPE_UNKNOWN:
-    FREE(rmask);
-    FREE(cmask);
+    free(rmask);
+    free(cmask);
     return NULL;
   default:
-    FREE(rmask);
-    FREE(cmask);
+    free(rmask);
+    free(cmask);
     return NULL;
   }
 
   B = SparseMatrix_from_coordinate_arrays(nz, nrow, ncol, irn, jcn, v, A->type, A->size);
-  FREE(cmask);
-  FREE(rmask);
-  FREE(irn);
-  FREE(jcn);
-  if (v) FREE(v);
+  free(cmask);
+  free(rmask);
+  free(irn);
+  free(jcn);
+  if (v) free(v);
 
 
   return B;
@@ -2474,30 +2335,30 @@ SparseMatrix SparseMatrix_get_submatrix(SparseMatrix A, int nrow, int ncol, int
 }
 
 SparseMatrix SparseMatrix_set_entries_to_real_one(SparseMatrix A){
-  real *a;
+  double *a;
   int i;
 
-  if (A->a) FREE(A->a);
-  A->a = MALLOC(sizeof(real)*((size_t)A->nz));
-  a = (real*) (A->a);
+  free(A->a);
+  A->a = MALLOC(sizeof(double)*((size_t)A->nz));
+  a = (double*) (A->a);
   for (i = 0; i < A->nz; i++) a[i] = 1.;
   A->type = MATRIX_TYPE_REAL;
-  A->size = sizeof(real);
+  A->size = sizeof(double);
   return A;
 
 }
 
-SparseMatrix SparseMatrix_from_dense(int m, int n, real *x){
+SparseMatrix SparseMatrix_from_dense(int m, int n, double *x){
   /* wrap a mxn matrix into a sparse matrix. the {i,j} entry of the matrix is in x[i*n+j], 0<=i<m; 0<=j<n */
   int i, j, *ja;
-  real *a;
+  double *a;
   SparseMatrix A = SparseMatrix_new(m, n, m*n, MATRIX_TYPE_REAL, FORMAT_CSR);
 
   A->ia[0] = 0;
   for (i = 1; i <= m; i++) (A->ia)[i] = (A->ia)[i-1] + n;
   
   ja = A->ja;
-  a = (real*) A->a;
+  a = (double*) A->a;
   for (i = 0; i < m; i++){
     for (j = 0; j < n; j++) {
       ja[j] = j;
@@ -2511,7 +2372,7 @@ SparseMatrix SparseMatrix_from_dense(int m, int n, real *x){
 }
 
 
-int SparseMatrix_distance_matrix(SparseMatrix D0, int weighted, real **dist0){
+int SparseMatrix_distance_matrix(SparseMatrix D0, int weighted, double **dist0){
   /*
     Input:
     D: the graph. If weighted, the entry values is used.
@@ -2523,18 +2384,18 @@ int SparseMatrix_distance_matrix(SparseMatrix D0, int weighted, real **dist0){
   SparseMatrix D = D0;
   int m = D->m, n = D->n;
   int *levelset_ptr = NULL, *levelset = NULL, *mask = NULL;
-  real *dist = NULL;
+  double *dist = NULL;
   int nlist, *list = NULL;
   int flag = 0, i, j, k, nlevel;
-  real dmax;
+  double dmax;
 
-  if (!SparseMatrix_is_symmetric(D, FALSE)){
-    D = SparseMatrix_symmetrize(D, FALSE);
+  if (!SparseMatrix_is_symmetric(D, false)){
+    D = SparseMatrix_symmetrize(D, false);
   }
 
   assert(m == n);
 
-  if (!(*dist0)) *dist0 = MALLOC(sizeof(real)*n*n);
+  if (!(*dist0)) *dist0 = MALLOC(sizeof(double)*n*n);
   for (i = 0; i < n*n; i++) (*dist0)[i] = -1;
 
   if (!weighted){
@@ -2555,14 +2416,13 @@ int SparseMatrix_distance_matrix(SparseMatrix D0, int weighted, real **dist0){
     }
   }
 
-  if (levelset_ptr) FREE(levelset_ptr);
-  if (levelset) FREE(levelset);
-  if (mask) FREE(mask);
+  free(levelset_ptr);
+  free(levelset);
+  free(mask);
   
   if (D != D0) SparseMatrix_delete(D);
-  if (list) FREE(list);
+  free(list);
   return flag;
-
 }
 
 SparseMatrix SparseMatrix_distance_matrix_khops(int khops, SparseMatrix D0, int weighted){
@@ -2578,13 +2438,13 @@ SparseMatrix SparseMatrix_distance_matrix_khops(int khops, SparseMatrix D0, int
   SparseMatrix D = D0, B, C;
   int m = D->m, n = D->n;
   int *levelset_ptr = NULL, *levelset = NULL, *mask = NULL;
-  real *dist = NULL;
+  double *dist = NULL;
   int nlist, *list = NULL;
   int flag = 0, i, j, k, itmp, nlevel;
-  real dmax, dtmp;
+  double dmax, dtmp;
 
-  if (!SparseMatrix_is_symmetric(D, FALSE)){
-    D = SparseMatrix_symmetrize(D, FALSE);
+  if (!SparseMatrix_is_symmetric(D, false)){
+    D = SparseMatrix_symmetrize(D, false);
   }
 
   assert(m == n);
@@ -2597,13 +2457,13 @@ SparseMatrix SparseMatrix_distance_matrix_khops(int khops, SparseMatrix D0, int
       for (i = 0; i < nlevel; i++) {
 	for (j = levelset_ptr[i]; j < levelset_ptr[i+1]; j++){
 	  itmp = levelset[j]; dtmp = i;
-	  if (k != itmp) B = SparseMatrix_coordinate_form_add_entries(B, 1, &k, &itmp, &dtmp);
+	  if (k != itmp) B = SparseMatrix_coordinate_form_add_entry(B, k, itmp, &dtmp);
 	}
       }
      }
   } else {
     list = MALLOC(sizeof(int)*n);
-    dist = MALLOC(sizeof(real)*n);
+    dist = MALLOC(sizeof(double)*n);
     /*
     Dijkstra_khops(khops, D, 60, dist, &nlist, list, &dmax);
     for (j = 0; j < nlist; j++){
@@ -2615,7 +2475,7 @@ SparseMatrix SparseMatrix_distance_matrix_khops(int khops, SparseMatrix D0, int
       fprintf(stderr,"{%d,%d}=%f,",94,list[j],dist[list[j]]);
     }
     fprintf(stderr,"\n");
-    exit(1);
+    graphviz_exit(1);
 
     */
 
@@ -2632,7 +2492,7 @@ SparseMatrix SparseMatrix_distance_matrix_khops(int khops, SparseMatrix D0, int
       }
       for (j = 0; j < nlist; j++){
 	itmp = list[j]; dtmp = dist[itmp];
-	if (k != itmp) B = SparseMatrix_coordinate_form_add_entries(B, 1, &k, &itmp, &dtmp);
+	if (k != itmp) B = SparseMatrix_coordinate_form_add_entry(B, k, itmp, &dtmp);
       }
    }
   }
@@ -2640,13 +2500,13 @@ SparseMatrix SparseMatrix_distance_matrix_khops(int khops, SparseMatrix D0, int
   C = SparseMatrix_from_coordinate_format(B);
   SparseMatrix_delete(B);
 
-  if (levelset_ptr) FREE(levelset_ptr);
-  if (levelset) FREE(levelset);
-  if (mask) FREE(mask);
-  if (dist) FREE(dist);
+  free(levelset_ptr);
+  free(levelset);
+  free(mask);
+  free(dist);
 
   if (D != D0) SparseMatrix_delete(D);
-  if (list) FREE(list);
+  free(list);
   /* I can not find a reliable way to make the matrix symmetric. Right now I use a mask array to
      limit consider of only nodes with in k hops, but even this is not symmetric. e.g.,
      . 10  10    10  10
@@ -2659,7 +2519,7 @@ SparseMatrix SparseMatrix_distance_matrix_khops(int khops, SparseMatrix D0, int
      .
      may be there is a better way to ensure symmetric, but for now we just symmetrize it
   */
-  D = SparseMatrix_symmetrize(C, FALSE);
+  D = SparseMatrix_symmetrize(C, false);
   SparseMatrix_delete(C);
   return D;
 
