@@ -10,10 +10,10 @@
 
 #include "config.h"
 
+#include <math.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
 
 #ifdef _WIN32
 #include <io.h>
@@ -52,44 +52,6 @@ static void figptarray(GVJ_t *job, pointf * A, int n, int close)
     gvputs(job, "\n");
 }
 
-static char *fig_string(char *s)
-{
-    static char *buf = NULL;
-    static size_t bufsize = 0;
-    size_t pos = 0;
-    char *p;
-    char c;
-
-    if (!buf) {
-        bufsize = 64;
-        buf = malloc(bufsize * sizeof(char));
-    }
-
-    p = buf;
-    while ((c = *s++)) {
-        if (pos > (bufsize - 8)) {
-            bufsize *= 2;
-            buf = realloc(buf, bufsize * sizeof(char));
-            p = buf + pos;
-        }
-        if (isascii(c)) {
-            if (c == '\\') {
-                *p++ = '\\';
-                pos++;
-            }
-            *p++ = c;
-            pos++;
-        } else {
-            *p++ = '\\';
-            sprintf(p, "%03o", (unsigned)c);
-            p += 3;
-            pos += 4;
-        }
-    }
-    *p = '\0';
-    return buf;
-}
-
 static int figColorResolve(int *new, unsigned char r, unsigned char g,
   unsigned char b)
 {
@@ -214,26 +176,36 @@ static void fig_end_graph(GVJ_t * job)
 
 static void fig_begin_page(GVJ_t * job)
 {
+    (void)job;
+
     Depth = 2;
 }
 
 static void fig_begin_node(GVJ_t * job)
 {
+    (void)job;
+
     Depth = 1;
 }
 
 static void fig_end_node(GVJ_t * job)
 {
+    (void)job;
+
     Depth = 2;
 }
 
 static void fig_begin_edge(GVJ_t * job)
 {
+    (void)job;
+
     Depth = 0;
 }
 
 static void fig_end_edge(GVJ_t * job)
 {
+    (void)job;
+
     Depth = 2;
 }
 
@@ -282,10 +254,11 @@ static void fig_textspan(GVJ_t * job, pointf p, textspan_t * span)
 	$A	\\in	M_0$\001
 */
     gvprintf(job,
-            "%d %d %d %d %d %d %.1f %.4f %d %.1f %.1f %d %d %s\\001\n",
+            "%d %d %d %d %d %d %.1f %.4f %d %.1f %.1f %d %d ",
             object_code, sub_type, color, depth, pen_style, font,
-            font_size, angle, font_flags, height, length, ROUND(p.x), ROUND((p.y-72.0)),
-            fig_string(span->str));
+            font_size, angle, font_flags, height, length, ROUND(p.x), ROUND((p.y-72.0)));
+    gvputs_nonascii(job, span->str);
+    gvputs(job, "\\001\n");
 }
 
 static void fig_ellipse(GVJ_t * job, pointf * A, int filled)
@@ -295,7 +268,7 @@ static void fig_ellipse(GVJ_t * job, pointf * A, int filled)
     int object_code = 1;        /* always 1 for ellipse */
     int sub_type = 1;           /* ellipse defined by radii */
     int line_style;		/* solid, dotted, dashed */
-    int thickness = obj->penwidth;
+    double thickness = round(obj->penwidth);
     int pen_color = obj->pencolor.u.index;
     int fill_color = obj->fillcolor.u.index;
     int depth = Depth;
@@ -317,7 +290,7 @@ static void fig_ellipse(GVJ_t * job, pointf * A, int filled)
     end_y = ROUND(A[1].y);
 
     gvprintf(job,
-            "%d %d %d %d %d %d %d %d %d %.3f %d %.4f %d %d %d %d %d %d %d %d\n",
+            "%d %d %d %.0f %d %d %d %d %d %.3f %d %.4f %d %d %d %d %d %d %d %d\n",
             object_code, sub_type, line_style, thickness, pen_color,
             fill_color, depth, pen_style, area_fill, style_val, direction,
             angle, center_x, center_y, radius_x, radius_y, start_x,
@@ -335,7 +308,7 @@ static void fig_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
     int object_code = 3;        /* always 3 for spline */
     int sub_type;
     int line_style;		/* solid, dotted, dashed */
-    int thickness = obj->penwidth;
+    double thickness = round(obj->penwidth);
     int pen_color = obj->pencolor.u.index;
     int fill_color = obj->fillcolor.u.index;
     int depth = Depth;
@@ -399,7 +372,7 @@ static void fig_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
         }
     }
 
-    gvprintf(job, "%d %d %d %d %d %d %d %d %d %.1f %d %d %d %d\n",
+    gvprintf(job, "%d %d %d %.0f %d %d %d %d %d %.1f %d %d %d %d\n",
             object_code,
             sub_type,
             line_style,
@@ -426,7 +399,7 @@ static void fig_polygon(GVJ_t * job, pointf * A, int n, int filled)
     int object_code = 2;        /* always 2 for polyline */
     int sub_type = 3;           /* always 3 for polygon */
     int line_style;		/* solid, dotted, dashed */
-    int thickness = obj->penwidth;
+    double thickness = round(obj->penwidth);
     int pen_color = obj->pencolor.u.index;
     int fill_color = obj->fillcolor.u.index;
     int depth = Depth;
@@ -443,7 +416,7 @@ static void fig_polygon(GVJ_t * job, pointf * A, int n, int filled)
     fig_line_style(obj, &line_style, &style_val);
 
     gvprintf(job,
-            "%d %d %d %d %d %d %d %d %d %.1f %d %d %d %d %d %d\n",
+            "%d %d %d %.0f %d %d %d %d %d %.1f %d %d %d %d %d %d\n",
             object_code, sub_type, line_style, thickness, pen_color,
             fill_color, depth, pen_style, area_fill, style_val, join_style,
             cap_style, radius, forward_arrow, backward_arrow, npoints);
@@ -457,7 +430,7 @@ static void fig_polyline(GVJ_t * job, pointf * A, int n)
     int object_code = 2;        /* always 2 for polyline */
     int sub_type = 1;           /* always 1 for polyline */
     int line_style;		/* solid, dotted, dashed */
-    int thickness = obj->penwidth;
+    double thickness = round(obj->penwidth);
     int pen_color = obj->pencolor.u.index;
     int fill_color = 0;
     int depth = Depth;
@@ -474,7 +447,7 @@ static void fig_polyline(GVJ_t * job, pointf * A, int n)
     fig_line_style(obj, &line_style, &style_val);
 
     gvprintf(job,
-            "%d %d %d %d %d %d %d %d %d %.1f %d %d %d %d %d %d\n",
+            "%d %d %d %.0f %d %d %d %d %d %.1f %d %d %d %d %d %d\n",
             object_code, sub_type, line_style, thickness, pen_color,
             fill_color, depth, pen_style, area_fill, style_val, join_style,
             cap_style, radius, forward_arrow, backward_arrow, npoints);
